subrules = [
   [r'\bneqmx\b','bbb.neqmx'],
   [r'\bnumvar\b','bbb.numvar'],
   [r'\bnumvarbwpad\b','bbb.numvarbwpad'],
   [r'\bcsfaclb\b','bbb.csfaclb'],
   [r'\bcsfacrb\b','bbb.csfacrb'],
   [r'\bcsfacti\b','bbb.csfacti'],
   [r'\bcslim\b','bbb.cslim'],
   [r'\bdcslim\b','bbb.dcslim'],
   [r'\blnlam\b','bbb.lnlam'],
   [r'\bmethe\b','bbb.methe'],
   [r'\bmethu\b','bbb.methu'],
   [r'\bmethn\b','bbb.methn'],
   [r'\bmethi\b','bbb.methi'],
   [r'\bmethg\b','bbb.methg'],
   [r'\bmethp\b','bbb.methp'],
   [r'\bisgxvon\b','bbb.isgxvon'],
   [r'\bishavisy\b','bbb.ishavisy'],
   [r'\bcfaccony\b','bbb.cfaccony'],
   [r'\bisvylog\b','bbb.isvylog'],
   [r'\bisintlog\b','bbb.isintlog'],
   [r'\bconcap\b','bbb.concap'],
   [r'\bconvis\b','bbb.convis'],
   [r'\bcniatol\b','bbb.cniatol'],
   [r'\bcngatol\b','bbb.cngatol'],
   [r'\bcupatol\b','bbb.cupatol'],
   [r'\bcteatol\b','bbb.cteatol'],
   [r'\bctiatol\b','bbb.ctiatol'],
   [r'\bcphiatol\b','bbb.cphiatol'],
   [r'\btolbf\b','bbb.tolbf'],
   [r'\btadj\b','bbb.tadj'],
   [r'\bicnuiz\b','bbb.icnuiz'],
   [r'\bicnucx\b','bbb.icnucx'],
   [r'\bcnuiz\b','bbb.cnuiz'],
   [r'\bcnucx\b','bbb.cnucx'],
   [r'\bisrecmon\b','bbb.isrecmon'],
   [r'\bcfrecom\b','bbb.cfrecom'],
   [r'\bigas\b','bbb.igas'],
   [r'\bngbackg\b','bbb.ngbackg'],
   [r'\bingb\b','bbb.ingb'],
   [r'\bfacngbackg2ngs\b','bbb.facngbackg2ngs'],
   [r'\bnzbackg\b','bbb.nzbackg'],
   [r'\binzb\b','bbb.inzb'],
   [r'\bfacnzbackg2nis\b','bbb.facnzbackg2nis'],
   [r'\bupclng\b','bbb.upclng'],
   [r'\bfacupclng2ups\b','bbb.facupclng2ups'],
   [r'\btebg\b','bbb.tebg'],
   [r'\btibg\b','bbb.tibg'],
   [r'\biteb\b','bbb.iteb'],
   [r'\btemin\b','bbb.temin'],
   [r'\btemin2\b','bbb.temin2'],
   [r'\bpwrbkg_c\b','bbb.pwrbkg_c'],
   [r'\bpwribkg_c\b','bbb.pwribkg_c'],
   [r'\bcfwjdotelim\b','bbb.cfwjdotelim'],
   [r'\bnlimix\b','bbb.nlimix'],
   [r'\bnlimiy\b','bbb.nlimiy'],
   [r'\bnlimgx\b','bbb.nlimgx'],
   [r'\bnlimgy\b','bbb.nlimgy'],
   [r'\bis1D_gbx\b','bbb.is1D_gbx'],
   [r'\bxgbx\b','bbb.xgbx'],
   [r'\bixgb\b','bbb.ixgb'],
   [r'\bagdc\b','bbb.agdc'],
   [r'\bpcolwid\b','bbb.pcolwid'],
   [r'\beion\b','bbb.eion'],
   [r'\bediss\b','bbb.ediss'],
   [r'\bebind\b','bbb.ebind'],
   [r'\btfcx\b','bbb.tfcx'],
   [r'\btfcy\b','bbb.tfcy'],
   [r'\bafix\b','bbb.afix'],
   [r'\bcoef\b','bbb.coef'],
   [r'\bce\b','bbb.ce'],
   [r'\bci\b','bbb.ci'],
   [r'\bncrhs\b','bbb.ncrhs'],
   [r'\bistep\b','bbb.istep'],
   [r'\biter\b','bbb.iter'],
   [r'\bdp1\b','bbb.dp1'],
   [r'\bqfl\b','bbb.qfl'],
   [r'\bcsh\b','bbb.csh'],
   [r'\bqsh\b','bbb.qsh'],
   [r'\bmfl\b','bbb.mfl'],
   [r'\bmsh\b','bbb.msh'],
   [r'\bro\b','bbb.ro'],
   [r'\bcs\b','bbb.cs'],
   [r'\bfxe\b','bbb.fxe'],
   [r'\bctaue\b','bbb.ctaue'],
   [r'\bfxi\b','bbb.fxi'],
   [r'\bctaui\b','bbb.ctaui'],
   [r'\bzcoef\b','bbb.zcoef'],
   [r'\bcoef1\b','bbb.coef1'],
   [r'\bcnurn\b','bbb.cnurn'],
   [r'\bcnuru\b','bbb.cnuru'],
   [r'\bcnure\b','bbb.cnure'],
   [r'\bcnuri\b','bbb.cnuri'],
   [r'\bcnurg\b','bbb.cnurg'],
   [r'\bcnurp\b','bbb.cnurp'],
   [r'\bnurlxn\b','bbb.nurlxn'],
   [r'\bnurlxu\b','bbb.nurlxu'],
   [r'\bnurlxe\b','bbb.nurlxe'],
   [r'\bnurlxi\b','bbb.nurlxi'],
   [r'\bnurlxg\b','bbb.nurlxg'],
   [r'\bnurlxp\b','bbb.nurlxp'],
   [r'\blabel\b','bbb.label'],
   [r'\brnewpot\b','bbb.rnewpot'],
   [r'\br0slab\b','bbb.r0slab'],
   [r'\bishymol\b','bbb.ishymol'],
   [r'\bte_s_dis\b','bbb.te_s_dis'],
   [r'\bisfqpave\b','bbb.isfqpave'],
   [r'\bsvrpkg\b','bbb.svrpkg'],
   [r'\bpetscoptfile\b','bbb.petscoptfile'],
   [r'\bpetscopts\b','bbb.petscopts'],
   [r'\bisgpye\b','bbb.isgpye'],
   [r'\biigsp\b','bbb.iigsp'],
   [r'\bfnnuiz\b','bbb.fnnuiz'],
   [r'\bitrap_negni\b','bbb.itrap_negni'],
   [r'\bitrap_negt\b','bbb.itrap_negt'],
   [r'\bitrap_negng\b','bbb.itrap_negng'],
   [r'\bisybdryog\b','bbb.isybdryog'],
   [r'\bisybdrywd\b','bbb.isybdrywd'],
   [r'\bisxmpog\b','bbb.isxmpog'],
   [r'\bineudif\b','bbb.ineudif'],
   [r'\bthetar\b','bbb.thetar'],
   [r'\bisbcwdt\b','bbb.isbcwdt'],
   [r'\bishosor\b','bbb.ishosor'],
   [r'\biseesorave\b','bbb.iseesorave'],
   [r'\bispsorave\b','bbb.ispsorave'],
   [r'\bfsprd\b','bbb.fsprd'],
   [r'\bissyvxpt0\b','bbb.issyvxpt0'],
   [r'\bisrrvave\b','bbb.isrrvave'],
   [r'\brr_fac\b','bbb.rr_fac'],
   [r'\brrmin\b','bbb.rrmin'],
   [r'\bisdtsfscal\b','bbb.isdtsfscal'],
   [r'\bfrfqpn\b','bbb.frfqpn'],
   [r'\bcffqpsat\b','bbb.cffqpsat'],
   [r'\bisplflxl\b','bbb.isplflxl'],
   [r'\bisplflxlv\b','bbb.isplflxlv'],
   [r'\bisplflxlgx\b','bbb.isplflxlgx'],
   [r'\bisplflxlgxy\b','bbb.isplflxlgxy'],
   [r'\biswflxlgy\b','bbb.iswflxlgy'],
   [r'\bisplflxlvgx\b','bbb.isplflxlvgx'],
   [r'\bisplflxlvgxy\b','bbb.isplflxlvgxy'],
   [r'\biswflxlvgy\b','bbb.iswflxlvgy'],
   [r'\bisplflxltgx\b','bbb.isplflxltgx'],
   [r'\bisplflxltgxy\b','bbb.isplflxltgxy'],
   [r'\biswflxltgy\b','bbb.iswflxltgy'],
   [r'\bflalfipl\b','bbb.flalfipl'],
   [r'\bflalfepl\b','bbb.flalfepl'],
   [r'\bisfeexpl0\b','bbb.isfeexpl0'],
   [r'\bisfeixpl0\b','bbb.isfeixpl0'],
   [r'\bisofric\b','bbb.isofric'],
   [r'\bdel_te_ro\b','bbb.del_te_ro'],
   [r'\biskaboom\b','bbb.iskaboom'],
   [r'\bisnglf\b','bbb.isnglf'],
   [r'\bnglfix\b','bbb.nglfix'],
   [r'\bisngrf\b','bbb.isngrf'],
   [r'\bngrfix\b','bbb.ngrfix'],
   [r'\bisnion\b','bbb.isnion'],
   [r'\bisupon\b','bbb.isupon'],
   [r'\bisup1up2\b','bbb.isup1up2'],
   [r'\brup21\b','bbb.rup21'],
   [r'\bisupgon\b','bbb.isupgon'],
   [r'\bisteon\b','bbb.isteon'],
   [r'\bistion\b','bbb.istion'],
   [r'\bisngon\b','bbb.isngon'],
   [r'\bistgon\b','bbb.istgon'],
   [r'\bisphion\b','bbb.isphion'],
   [r'\bisphiofft\b','bbb.isphiofft'],
   [r'\bisnewpot\b','bbb.isnewpot'],
   [r'\bisnionxy\b','bbb.isnionxy'],
   [r'\bisuponxy\b','bbb.isuponxy'],
   [r'\bisteonxy\b','bbb.isteonxy'],
   [r'\bistionxy\b','bbb.istionxy'],
   [r'\bisngonxy\b','bbb.isngonxy'],
   [r'\bistgonxy\b','bbb.istgonxy'],
   [r'\bisphionxy\b','bbb.isphionxy'],
   [r'\bisnioffxy\b','bbb.isnioffxy'],
   [r'\bisupoffxy\b','bbb.isupoffxy'],
   [r'\bisteoffxy\b','bbb.isteoffxy'],
   [r'\bistioffxy\b','bbb.istioffxy'],
   [r'\bisngoffxy\b','bbb.isngoffxy'],
   [r'\bistgoffxy\b','bbb.istgoffxy'],
   [r'\bisphioffxy\b','bbb.isphioffxy'],
   [r'\bfdtnixy\b','bbb.fdtnixy'],
   [r'\bfdtupxy\b','bbb.fdtupxy'],
   [r'\bfdttexy\b','bbb.fdttexy'],
   [r'\bfdttixy\b','bbb.fdttixy'],
   [r'\bfdtngxy\b','bbb.fdtngxy'],
   [r'\bfdttgxy\b','bbb.fdttgxy'],
   [r'\bfdtphixy\b','bbb.fdtphixy'],
   [r'\bisugfm1side\b','bbb.isugfm1side'],
   [r'\bisnupdot1sd\b','bbb.isnupdot1sd'],
   [r'\bisphicore0\b','bbb.isphicore0'],
   [r'\bis_z0_imp_const\b','bbb.is_z0_imp_const'],
   [r'\bz0_imp_const\b','bbb.z0_imp_const'],
   [r'\biondenseqn\b','bbb.iondenseqn'],
   [r'\bcnfx\b','bbb.cnfx'],
   [r'\bcnfy\b','bbb.cnfy'],
   [r'\bcnsor\b','bbb.cnsor'],
   [r'\bcfneut\b','bbb.cfneut'],
   [r'\bcfnidh\b','bbb.cfnidh'],
   [r'\bcfupcx\b','bbb.cfupcx'],
   [r'\bcfticx\b','bbb.cfticx'],
   [r'\bcfupimpg\b','bbb.cfupimpg'],
   [r'\bcftiimpg\b','bbb.cftiimpg'],
   [r'\bcmneut\b','bbb.cmneut'],
   [r'\bcnflux\b','bbb.cnflux'],
   [r'\bchradi\b','bbb.chradi'],
   [r'\bchradr\b','bbb.chradr'],
   [r'\bchioniz\b','bbb.chioniz'],
   [r'\bifxnsgi\b','bbb.ifxnsgi'],
   [r'\bcne_sgvi\b','bbb.cne_sgvi'],
   [r'\bctsor\b','bbb.ctsor'],
   [r'\bceisor\b','bbb.ceisor'],
   [r'\bccoldsor\b','bbb.ccoldsor'],
   [r'\bcngfx\b','bbb.cngfx'],
   [r'\bcngfy\b','bbb.cngfy'],
   [r'\bcngmom\b','bbb.cngmom'],
   [r'\bcmwall\b','bbb.cmwall'],
   [r'\bcngtgx\b','bbb.cngtgx'],
   [r'\bcngtgy\b','bbb.cngtgy'],
   [r'\bsxgsol\b','bbb.sxgsol'],
   [r'\bsxgpr\b','bbb.sxgpr'],
   [r'\bxstscal\b','bbb.xstscal'],
   [r'\brld2dxg\b','bbb.rld2dxg'],
   [r'\brld2dyg\b','bbb.rld2dyg'],
   [r'\bcngflox\b','bbb.cngflox'],
   [r'\bcngfloy\b','bbb.cngfloy'],
   [r'\bcngniflox\b','bbb.cngniflox'],
   [r'\bcngnifloy\b','bbb.cngnifloy'],
   [r'\bcngsor\b','bbb.cngsor'],
   [r'\bcdifg\b','bbb.cdifg'],
   [r'\blgmax\b','bbb.lgmax'],
   [r'\blgtmax\b','bbb.lgtmax'],
   [r'\blgvmax\b','bbb.lgvmax'],
   [r'\brtg2ti\b','bbb.rtg2ti'],
   [r'\btgas\b','bbb.tgas'],
   [r'\bcmfx\b','bbb.cmfx'],
   [r'\bcmfy\b','bbb.cmfy'],
   [r'\bcpgx\b','bbb.cpgx'],
   [r'\bcfvisx\b','bbb.cfvisx'],
   [r'\bcfvisy\b','bbb.cfvisy'],
   [r'\bcfanomvisxg\b','bbb.cfanomvisxg'],
   [r'\bcfanomvisyg\b','bbb.cfanomvisyg'],
   [r'\bcfvisxn\b','bbb.cfvisxn'],
   [r'\bcfvisxy\b','bbb.cfvisxy'],
   [r'\bisvisxn_old\b','bbb.isvisxn_old'],
   [r'\bcfvxnrr\b','bbb.cfvxnrr'],
   [r'\bcfvisyn\b','bbb.cfvisyn'],
   [r'\bcfvcsx\b','bbb.cfvcsx'],
   [r'\bcfvcsy\b','bbb.cfvcsy'],
   [r'\bvboost\b','bbb.vboost'],
   [r'\bcvgp\b','bbb.cvgp'],
   [r'\bcfvgpx\b','bbb.cfvgpx'],
   [r'\bcfvgpy\b','bbb.cfvgpy'],
   [r'\bcfbgt\b','bbb.cfbgt'],
   [r'\bcfjhf\b','bbb.cfjhf'],
   [r'\bjhswitch\b','bbb.jhswitch'],
   [r'\bcf2ef\b','bbb.cf2ef'],
   [r'\bcfyef\b','bbb.cfyef'],
   [r'\bcftef\b','bbb.cftef'],
   [r'\bcf2bf\b','bbb.cf2bf'],
   [r'\bcfybf\b','bbb.cfybf'],
   [r'\bcfcbti\b','bbb.cfcbti'],
   [r'\bcfcurv\b','bbb.cfcurv'],
   [r'\bcfgradb\b','bbb.cfgradb'],
   [r'\bcfq2bf\b','bbb.cfq2bf'],
   [r'\bcfqybf\b','bbb.cfqybf'],
   [r'\bcfqyn\b','bbb.cfqyn'],
   [r'\bcfqym\b','bbb.cfqym'],
   [r'\bcfqydt\b','bbb.cfqydt'],
   [r'\bcf2dd\b','bbb.cf2dd'],
   [r'\bcfydd\b','bbb.cfydd'],
   [r'\bcftdd\b','bbb.cftdd'],
   [r'\bcfrd\b','bbb.cfrd'],
   [r'\bcfvisxneov\b','bbb.cfvisxneov'],
   [r'\bcfvisxneoq\b','bbb.cfvisxneoq'],
   [r'\bcfvycr\b','bbb.cfvycr'],
   [r'\bcfvycf\b','bbb.cfvycf'],
   [r'\bcfvyavis\b','bbb.cfvyavis'],
   [r'\bcfjve\b','bbb.cfjve'],
   [r'\bcfjp2\b','bbb.cfjp2'],
   [r'\bcfjpy\b','bbb.cfjpy'],
   [r'\bisnfmiy\b','bbb.isnfmiy'],
   [r'\bcfnfmiy\b','bbb.cfnfmiy'],
   [r'\bcnimp\b','bbb.cnimp'],
   [r'\bfac2sp\b','bbb.fac2sp'],
   [r'\bcftnm\b','bbb.cftnm'],
   [r'\bcfupjr\b','bbb.cfupjr'],
   [r'\bcfcximp1\b','bbb.cfcximp1'],
   [r'\bcfcximp2\b','bbb.cfcximp2'],
   [r'\bcfnetap\b','bbb.cfnetap'],
   [r'\bfcdif\b','bbb.fcdif'],
   [r'\bcfmsor\b','bbb.cfmsor'],
   [r'\bcpiup\b','bbb.cpiup'],
   [r'\bcfloyi\b','bbb.cfloyi'],
   [r'\bcfloye\b','bbb.cfloye'],
   [r'\bcfcvte\b','bbb.cfcvte'],
   [r'\bcfcvti\b','bbb.cfcvti'],
   [r'\bcfcvtg\b','bbb.cfcvtg'],
   [r'\bcfloxiplt\b','bbb.cfloxiplt'],
   [r'\bcfloygwall\b','bbb.cfloygwall'],
   [r'\bexjbdry\b','bbb.exjbdry'],
   [r'\bcfgpijr\b','bbb.cfgpijr'],
   [r'\biszeffcon\b','bbb.iszeffcon'],
   [r'\bzeffcon\b','bbb.zeffcon'],
   [r'\balftng\b','bbb.alftng'],
   [r'\bcfqya\b','bbb.cfqya'],
   [r'\bcfqyao\b','bbb.cfqyao'],
   [r'\bcfqyae\b','bbb.cfqyae'],
   [r'\bcfqyai\b','bbb.cfqyai'],
   [r'\bcftgcond\b','bbb.cftgcond'],
   [r'\bcftgeqp\b','bbb.cftgeqp'],
   [r'\bibctepl\b','bbb.ibctepl'],
   [r'\bibctipl\b','bbb.ibctipl'],
   [r'\bibctepr\b','bbb.ibctepr'],
   [r'\bibctipr\b','bbb.ibctipr'],
   [r'\bisphilbc\b','bbb.isphilbc'],
   [r'\bisphirbc\b','bbb.isphirbc'],
   [r'\biphibcc\b','bbb.iphibcc'],
   [r'\biphibcwi\b','bbb.iphibcwi'],
   [r'\biphibcwo\b','bbb.iphibcwo'],
   [r'\bphiwi\b','bbb.phiwi'],
   [r'\bphiwo\b','bbb.phiwo'],
   [r'\bphintewi\b','bbb.phintewi'],
   [r'\bphintewo\b','bbb.phintewo'],
   [r'\bncore\b','bbb.ncore'],
   [r'\bupcore\b','bbb.upcore'],
   [r'\bngcore\b','bbb.ngcore'],
   [r'\btgcore\b','bbb.tgcore'],
   [r'\bisnicore\b','bbb.isnicore'],
   [r'\bisupcore\b','bbb.isupcore'],
   [r'\bisngcore\b','bbb.isngcore'],
   [r'\bistgcore\b','bbb.istgcore'],
   [r'\bcurcore\b','bbb.curcore'],
   [r'\blzcore\b','bbb.lzcore'],
   [r'\blzflux\b','bbb.lzflux'],
   [r'\butorave\b','bbb.utorave'],
   [r'\bicoreelec\b','bbb.icoreelec'],
   [r'\beycore\b','bbb.eycore'],
   [r'\bcfniybbo\b','bbb.cfniybbo'],
   [r'\bcfniydbo\b','bbb.cfniydbo'],
   [r'\bcfeeybbo\b','bbb.cfeeybbo'],
   [r'\bcfeeydbo\b','bbb.cfeeydbo'],
   [r'\bcfeexdbo\b','bbb.cfeexdbo'],
   [r'\bcfeixdbo\b','bbb.cfeixdbo'],
   [r'\bcfqybbo\b','bbb.cfqybbo'],
   [r'\bcfqydbo\b','bbb.cfqydbo'],
   [r'\bnfqya0core\b','bbb.nfqya0core'],
   [r'\bnfqya0pf\b','bbb.nfqya0pf'],
   [r'\bnfqya0ow\b','bbb.nfqya0ow'],
   [r'\bixfixnc\b','bbb.ixfixnc'],
   [r'\bincixc\b','bbb.incixc'],
   [r'\btcoree\b','bbb.tcoree'],
   [r'\btcorei\b','bbb.tcorei'],
   [r'\btedge\b','bbb.tedge'],
   [r'\btepltl\b','bbb.tepltl'],
   [r'\btipltl\b','bbb.tipltl'],
   [r'\btepltr\b','bbb.tepltr'],
   [r'\btipltr\b','bbb.tipltr'],
   [r'\btbmin\b','bbb.tbmin'],
   [r'\bnbmin\b','bbb.nbmin'],
   [r'\bngbmin\b','bbb.ngbmin'],
   [r'\bistewc\b','bbb.istewc'],
   [r'\bistiwc\b','bbb.istiwc'],
   [r'\bistepfc\b','bbb.istepfc'],
   [r'\bistipfc\b','bbb.istipfc'],
   [r'\btewalli\b','bbb.tewalli'],
   [r'\btiwalli\b','bbb.tiwalli'],
   [r'\btewallo\b','bbb.tewallo'],
   [r'\btiwallo\b','bbb.tiwallo'],
   [r'\btgwall\b','bbb.tgwall'],
   [r'\blyte\b','bbb.lyte'],
   [r'\bisulytex\b','bbb.isulytex'],
   [r'\blytex\b','bbb.lytex'],
   [r'\blyti\b','bbb.lyti'],
   [r'\bisulytix\b','bbb.isulytix'],
   [r'\blytix\b','bbb.lytix'],
   [r'\blyphi\b','bbb.lyphi'],
   [r'\bisulyphix\b','bbb.isulyphix'],
   [r'\blyphix\b','bbb.lyphix'],
   [r'\bisextrnp\b','bbb.isextrnp'],
   [r'\bisextrnpf\b','bbb.isextrnpf'],
   [r'\bisextrtpf\b','bbb.isextrtpf'],
   [r'\bisextrngc\b','bbb.isextrngc'],
   [r'\bisextrnw\b','bbb.isextrnw'],
   [r'\bisextrtw\b','bbb.isextrtw'],
   [r'\biflcore\b','bbb.iflcore'],
   [r'\bpcoree\b','bbb.pcoree'],
   [r'\bpcorei\b','bbb.pcorei'],
   [r'\bifluxni\b','bbb.ifluxni'],
   [r'\bckinfl\b','bbb.ckinfl'],
   [r'\bisupss\b','bbb.isupss'],
   [r'\bisbohmms\b','bbb.isbohmms'],
   [r'\bisnwconi\b','bbb.isnwconi'],
   [r'\bisnwcono\b','bbb.isnwcono'],
   [r'\bnwalli\b','bbb.nwalli'],
   [r'\bnwallo\b','bbb.nwallo'],
   [r'\bnwimin\b','bbb.nwimin'],
   [r'\bnwomin\b','bbb.nwomin'],
   [r'\bncoremin\b','bbb.ncoremin'],
   [r'\blyni\b','bbb.lyni'],
   [r'\bisulynix\b','bbb.isulynix'],
   [r'\blynix\b','bbb.lynix'],
   [r'\blynicore\b','bbb.lynicore'],
   [r'\blyup\b','bbb.lyup'],
   [r'\bisulyupx\b','bbb.isulyupx'],
   [r'\blyupx\b','bbb.lyupx'],
   [r'\bnwsor\b','bbb.nwsor'],
   [r'\bigasi\b','bbb.igasi'],
   [r'\bigaso\b','bbb.igaso'],
   [r'\bigspsori\b','bbb.igspsori'],
   [r'\bigspsoro\b','bbb.igspsoro'],
   [r'\bissorlb\b','bbb.issorlb'],
   [r'\bjxsori\b','bbb.jxsori'],
   [r'\bjxsoro\b','bbb.jxsoro'],
   [r'\bxgasi\b','bbb.xgasi'],
   [r'\bxgaso\b','bbb.xgaso'],
   [r'\bwgasi\b','bbb.wgasi'],
   [r'\bwgaso\b','bbb.wgaso'],
   [r'\balbdsi\b','bbb.albdsi'],
   [r'\balbdso\b','bbb.albdso'],
   [r'\bchemsputi\b','bbb.chemsputi'],
   [r'\bchemsputo\b','bbb.chemsputo'],
   [r'\bmatwsi\b','bbb.matwsi'],
   [r'\bmatwso\b','bbb.matwso'],
   [r'\bissori\b','bbb.issori'],
   [r'\biesori\b','bbb.iesori'],
   [r'\bissoro\b','bbb.issoro'],
   [r'\biesoro\b','bbb.iesoro'],
   [r'\biwalli\b','bbb.iwalli'],
   [r'\biwallo\b','bbb.iwallo'],
   [r'\bncpli\b','bbb.ncpli'],
   [r'\bncplo\b','bbb.ncplo'],
   [r'\bcplsori\b','bbb.cplsori'],
   [r'\bcplsoro\b','bbb.cplsoro'],
   [r'\biscpli\b','bbb.iscpli'],
   [r'\biscplo\b','bbb.iscplo'],
   [r'\bfwsori\b','bbb.fwsori'],
   [r'\bfwsoro\b','bbb.fwsoro'],
   [r'\bfngysi\b','bbb.fngysi'],
   [r'\bfngyi_use\b','bbb.fngyi_use'],
   [r'\bfngysig\b','bbb.fngysig'],
   [r'\bfngyso\b','bbb.fngyso'],
   [r'\bfngyo_use\b','bbb.fngyo_use'],
   [r'\bfngysog\b','bbb.fngysog'],
   [r'\balbedoo\b','bbb.albedoo'],
   [r'\balbedoog\b','bbb.albedoog'],
   [r'\balbedoi\b','bbb.albedoi'],
   [r'\balbedoig\b','bbb.albedoig'],
   [r'\bmatwallo\b','bbb.matwallo'],
   [r'\bmatwallog\b','bbb.matwallog'],
   [r'\bmatwalli\b','bbb.matwalli'],
   [r'\bmatwallig\b','bbb.matwallig'],
   [r'\bsinphi\b','bbb.sinphi'],
   [r'\bisfixlb\b','bbb.isfixlb'],
   [r'\bisfixrb\b','bbb.isfixrb'],
   [r'\bnib\b','bbb.nib'],
   [r'\bupb\b','bbb.upb'],
   [r'\bteb\b','bbb.teb'],
   [r'\btib\b','bbb.tib'],
   [r'\byylb0\b','bbb.yylb0'],
   [r'\bywnii\b','bbb.ywnii'],
   [r'\bywnio\b','bbb.ywnio'],
   [r'\bywupi\b','bbb.ywupi'],
   [r'\bywupo\b','bbb.ywupo'],
   [r'\bywtei\b','bbb.ywtei'],
   [r'\bywteo\b','bbb.ywteo'],
   [r'\bywtii\b','bbb.ywtii'],
   [r'\bywtio\b','bbb.ywtio'],
   [r'\bnibprof\b','bbb.nibprof'],
   [r'\bupbprof\b','bbb.upbprof'],
   [r'\btebprof\b','bbb.tebprof'],
   [r'\btibprof\b','bbb.tibprof'],
   [r'\bengbsr\b','bbb.engbsr'],
   [r'\bepsbs\b','bbb.epsbs'],
   [r'\bisguardc\b','bbb.isguardc'],
   [r'\brlimiter\b','bbb.rlimiter'],
   [r'\bislimsor\b','bbb.islimsor'],
   [r'\bisutcore\b','bbb.isutcore'],
   [r'\bisupwi\b','bbb.isupwi'],
   [r'\bisupwo\b','bbb.isupwo'],
   [r'\bislbcn\b','bbb.islbcn'],
   [r'\bislbcu\b','bbb.islbcu'],
   [r'\bislbce\b','bbb.islbce'],
   [r'\bislbci\b','bbb.islbci'],
   [r'\bislbcg\b','bbb.islbcg'],
   [r'\bislbcp\b','bbb.islbcp'],
   [r'\bisph_sput\b','bbb.isph_sput'],
   [r'\bisi_sputw\b','bbb.isi_sputw'],
   [r'\bisi_sputpf\b','bbb.isi_sputpf'],
   [r'\bmatt\b','bbb.matt'],
   [r'\bmatp\b','bbb.matp'],
   [r'\bcion\b','bbb.cion'],
   [r'\bcizb\b','bbb.cizb'],
   [r'\bcrmb\b','bbb.crmb'],
   [r'\bisch_sput\b','bbb.isch_sput'],
   [r'\beincid\b','bbb.eincid'],
   [r'\bt_wall\b','bbb.t_wall'],
   [r'\bt_plat\b','bbb.t_plat'],
   [r'\btvwallo\b','bbb.tvwallo'],
   [r'\btvwalli\b','bbb.tvwalli'],
   [r'\btvplatlb\b','bbb.tvplatlb'],
   [r'\btvplatrb\b','bbb.tvplatrb'],
   [r'\bflux_in\b','bbb.flux_in'],
   [r'\bychem\b','bbb.ychem'],
   [r'\byld_carbi\b','bbb.yld_carbi'],
   [r'\byld_carbo\b','bbb.yld_carbo'],
   [r'\bfchemywi\b','bbb.fchemywi'],
   [r'\bfchemywo\b','bbb.fchemywo'],
   [r'\bfchemygwi\b','bbb.fchemygwi'],
   [r'\bfchemygwo\b','bbb.fchemygwo'],
   [r'\bfchemyiwi\b','bbb.fchemyiwi'],
   [r'\bfchemyiwo\b','bbb.fchemyiwo'],
   [r'\bfphysyiwi\b','bbb.fphysyiwi'],
   [r'\bfphysyiwo\b','bbb.fphysyiwo'],
   [r'\bfchemylb\b','bbb.fchemylb'],
   [r'\bfchemyrb\b','bbb.fchemyrb'],
   [r'\bfphysylb\b','bbb.fphysylb'],
   [r'\bfphysyrb\b','bbb.fphysyrb'],
   [r'\bisexunif\b','bbb.isexunif'],
   [r'\bxcnearlb\b','bbb.xcnearlb'],
   [r'\bxcnearrb\b','bbb.xcnearrb'],
   [r'\bopenbox\b','bbb.openbox'],
   [r'\bkappa0\b','bbb.kappa0'],
   [r'\bkappamx\b','bbb.kappamx'],
   [r'\bfqpsatlb\b','bbb.fqpsatlb'],
   [r'\bfqpsatrb\b','bbb.fqpsatrb'],
   [r'\bcfueb\b','bbb.cfueb'],
   [r'\bikapmod\b','bbb.ikapmod'],
   [r'\bfvapi\b','bbb.fvapi'],
   [r'\bavapi\b','bbb.avapi'],
   [r'\bbvapi\b','bbb.bvapi'],
   [r'\bfvapo\b','bbb.fvapo'],
   [r'\bavapo\b','bbb.avapo'],
   [r'\bbvapo\b','bbb.bvapo'],
   [r'\btvapi\b','bbb.tvapi'],
   [r'\btvapo\b','bbb.tvapo'],
   [r'\bcfvytanbc\b','bbb.cfvytanbc'],
   [r'\btotfeexl\b','bbb.totfeexl'],
   [r'\btotfeexr\b','bbb.totfeexr'],
   [r'\btotfeixl\b','bbb.totfeixl'],
   [r'\btotfeixr\b','bbb.totfeixr'],
   [r'\bcgpl\b','bbb.cgpl'],
   [r'\bcgpld\b','bbb.cgpld'],
   [r'\bcgengpl\b','bbb.cgengpl'],
   [r'\bcgengw\b','bbb.cgengw'],
   [r'\bcgmompl\b','bbb.cgmompl'],
   [r'\bvgmomp\b','bbb.vgmomp'],
   [r'\bue_part_fluxelb\b','bbb.ue_part_fluxelb'],
   [r'\bue_part_fluxerb\b','bbb.ue_part_fluxerb'],
   [r'\bue_part_fluxeyi\b','bbb.ue_part_fluxeyi'],
   [r'\bue_part_fluxeyo\b','bbb.ue_part_fluxeyo'],
   [r'\bue_part_fluxh2p1lb\b','bbb.ue_part_fluxh2p1lb'],
   [r'\bue_part_fluxh2p1rb\b','bbb.ue_part_fluxh2p1rb'],
   [r'\bue_part_fluxh2p1yi\b','bbb.ue_part_fluxh2p1yi'],
   [r'\bue_part_fluxh2p1yo\b','bbb.ue_part_fluxh2p1yo'],
   [r'\bue_part_fluxh2lb\b','bbb.ue_part_fluxh2lb'],
   [r'\bue_part_fluxh2rb\b','bbb.ue_part_fluxh2rb'],
   [r'\bue_part_fluxh2yi\b','bbb.ue_part_fluxh2yi'],
   [r'\bue_part_fluxh2yo\b','bbb.ue_part_fluxh2yo'],
   [r'\bue_heat_fluxelb\b','bbb.ue_heat_fluxelb'],
   [r'\bue_heat_fluxerb\b','bbb.ue_heat_fluxerb'],
   [r'\bue_heat_fluxeyi\b','bbb.ue_heat_fluxeyi'],
   [r'\bue_heat_fluxeyo\b','bbb.ue_heat_fluxeyo'],
   [r'\bue_heat_fluxh2p1lb\b','bbb.ue_heat_fluxh2p1lb'],
   [r'\bue_heat_fluxh2p1rb\b','bbb.ue_heat_fluxh2p1rb'],
   [r'\bue_heat_fluxh2p1yi\b','bbb.ue_heat_fluxh2p1yi'],
   [r'\bue_heat_fluxh2p1yo\b','bbb.ue_heat_fluxh2p1yo'],
   [r'\bue_heat_fluxh2lb\b','bbb.ue_heat_fluxh2lb'],
   [r'\bue_heat_fluxh2rb\b','bbb.ue_heat_fluxh2rb'],
   [r'\bue_heat_fluxh2yi\b','bbb.ue_heat_fluxh2yi'],
   [r'\bue_heat_fluxh2yo\b','bbb.ue_heat_fluxh2yo'],
   [r'\bue_mean_engelb\b','bbb.ue_mean_engelb'],
   [r'\bue_mean_engerb\b','bbb.ue_mean_engerb'],
   [r'\bue_mean_engeyi\b','bbb.ue_mean_engeyi'],
   [r'\bue_mean_engeyo\b','bbb.ue_mean_engeyo'],
   [r'\bue_mean_engh2p1lb\b','bbb.ue_mean_engh2p1lb'],
   [r'\bue_mean_engh2p1rb\b','bbb.ue_mean_engh2p1rb'],
   [r'\bue_mean_engh2p1yi\b','bbb.ue_mean_engh2p1yi'],
   [r'\bue_mean_engh2p1yo\b','bbb.ue_mean_engh2p1yo'],
   [r'\bue_mean_engh2lb\b','bbb.ue_mean_engh2lb'],
   [r'\bue_mean_engh2rb\b','bbb.ue_mean_engh2rb'],
   [r'\bue_mean_engh2yi\b','bbb.ue_mean_engh2yi'],
   [r'\bue_mean_engh2yo\b','bbb.ue_mean_engh2yo'],
   [r'\bue_pot_engh2p1lb\b','bbb.ue_pot_engh2p1lb'],
   [r'\bue_pot_engh2p1rb\b','bbb.ue_pot_engh2p1rb'],
   [r'\bue_pot_engh2p1yi\b','bbb.ue_pot_engh2p1yi'],
   [r'\bue_pot_engh2p1yo\b','bbb.ue_pot_engh2p1yo'],
   [r'\brecylb\b','bbb.recylb'],
   [r'\brecyrb\b','bbb.recyrb'],
   [r'\brecylb_use\b','bbb.recylb_use'],
   [r'\brecyrb_use\b','bbb.recyrb_use'],
   [r'\brecycp\b','bbb.recycp'],
   [r'\brecycflb\b','bbb.recycflb'],
   [r'\brecycfrb\b','bbb.recycfrb'],
   [r'\brecycm\b','bbb.recycm'],
   [r'\brecycmlb_use\b','bbb.recycmlb_use'],
   [r'\brecycmrb_use\b','bbb.recycmrb_use'],
   [r'\brecycmlb\b','bbb.recycmlb'],
   [r'\brecycmrb\b','bbb.recycmrb'],
   [r'\brecyce\b','bbb.recyce'],
   [r'\brecycl\b','bbb.recycl'],
   [r'\brecycml\b','bbb.recycml'],
   [r'\brecycc\b','bbb.recycc'],
   [r'\balbedoc\b','bbb.albedoc'],
   [r'\balbedolb\b','bbb.albedolb'],
   [r'\balbedorb\b','bbb.albedorb'],
   [r'\bndatlb\b','bbb.ndatlb'],
   [r'\bndatrb\b','bbb.ndatrb'],
   [r'\bydatlb\b','bbb.ydatlb'],
   [r'\bydatrb\b','bbb.ydatrb'],
   [r'\brdatlb\b','bbb.rdatlb'],
   [r'\brdatrb\b','bbb.rdatrb'],
   [r'\balblb\b','bbb.alblb'],
   [r'\balbrb\b','bbb.albrb'],
   [r'\balbedo_by_user\b','bbb.albedo_by_user'],
   [r'\bfngxslb\b','bbb.fngxslb'],
   [r'\bfngxsrb\b','bbb.fngxsrb'],
   [r'\bfngxlb_use\b','bbb.fngxlb_use'],
   [r'\bfngxrb_use\b','bbb.fngxrb_use'],
   [r'\badatlb\b','bbb.adatlb'],
   [r'\badatrb\b','bbb.adatrb'],
   [r'\brecycw\b','bbb.recycw'],
   [r'\brecypf_use\b','bbb.recypf_use'],
   [r'\brecywall_use\b','bbb.recywall_use'],
   [r'\brecycwit\b','bbb.recycwit'],
   [r'\brecycwot\b','bbb.recycwot'],
   [r'\bisrefluxclip\b','bbb.isrefluxclip'],
   [r'\bsputtr\b','bbb.sputtr'],
   [r'\bsputtlb\b','bbb.sputtlb'],
   [r'\bsputtrb\b','bbb.sputtrb'],
   [r'\bsputflxlb\b','bbb.sputflxlb'],
   [r'\bsputflxrb\b','bbb.sputflxrb'],
   [r'\bsputflxw\b','bbb.sputflxw'],
   [r'\bsputflxpf\b','bbb.sputflxpf'],
   [r'\bngplatlb\b','bbb.ngplatlb'],
   [r'\bngplatrb\b','bbb.ngplatrb'],
   [r'\bipsputt_s\b','bbb.ipsputt_s'],
   [r'\bipsputt_e\b','bbb.ipsputt_e'],
   [r'\bnpltsor\b','bbb.npltsor'],
   [r'\bigaslb\b','bbb.igaslb'],
   [r'\bigasrb\b','bbb.igasrb'],
   [r'\bigspsorlb\b','bbb.igspsorlb'],
   [r'\bigspsorrb\b','bbb.igspsorrb'],
   [r'\bygaslb\b','bbb.ygaslb'],
   [r'\bygasrb\b','bbb.ygasrb'],
   [r'\bwgaslb\b','bbb.wgaslb'],
   [r'\bwgasrb\b','bbb.wgasrb'],
   [r'\bfvaplb\b','bbb.fvaplb'],
   [r'\bavaplb\b','bbb.avaplb'],
   [r'\bbvaplb\b','bbb.bvaplb'],
   [r'\bfvaprb\b','bbb.fvaprb'],
   [r'\bavaprb\b','bbb.avaprb'],
   [r'\bbvaprb\b','bbb.bvaprb'],
   [r'\btvaplb\b','bbb.tvaplb'],
   [r'\btvaprb\b','bbb.tvaprb'],
   [r'\bisextpltmod\b','bbb.isextpltmod'],
   [r'\bisextwallmod\b','bbb.isextwallmod'],
   [r'\bisoutwall\b','bbb.isoutwall'],
   [r'\bfngxextlb\b','bbb.fngxextlb'],
   [r'\bfngxextrb\b','bbb.fngxextrb'],
   [r'\bfngyexti\b','bbb.fngyexti'],
   [r'\bfngyexto\b','bbb.fngyexto'],
   [r'\bfeixextlb\b','bbb.feixextlb'],
   [r'\bfeixextrb\b','bbb.feixextrb'],
   [r'\bfeiyexti\b','bbb.feiyexti'],
   [r'\bfeiyexto\b','bbb.feiyexto'],
   [r'\bifixsrc\b','bbb.ifixsrc'],
   [r'\bifixpsor\b','bbb.ifixpsor'],
   [r'\bxxsrc\b','bbb.xxsrc'],
   [r'\byysrc\b','bbb.yysrc'],
   [r'\bc1n\b','bbb.c1n'],
   [r'\bc1e\b','bbb.c1e'],
   [r'\bc1i\b','bbb.c1i'],
   [r'\ba1n\b','bbb.a1n'],
   [r'\ba1e\b','bbb.a1e'],
   [r'\ba1i\b','bbb.a1i'],
   [r'\bb1n\b','bbb.b1n'],
   [r'\bb1e\b','bbb.b1e'],
   [r'\bb1i\b','bbb.b1i'],
   [r'\bi1\b','bbb.i1'],
   [r'\bi2\b','bbb.i2'],
   [r'\bi2p\b','bbb.i2p'],
   [r'\bi3\b','bbb.i3'],
   [r'\bi4\b','bbb.i4'],
   [r'\bi5\b','bbb.i5'],
   [r'\bi5m\b','bbb.i5m'],
   [r'\bi6\b','bbb.i6'],
   [r'\bi7\b','bbb.i7'],
   [r'\bi8\b','bbb.i8'],
   [r'\bj1\b','bbb.j1'],
   [r'\bj2\b','bbb.j2'],
   [r'\bj3\b','bbb.j3'],
   [r'\bj4\b','bbb.j4'],
   [r'\bj5\b','bbb.j5'],
   [r'\bj5m\b','bbb.j5m'],
   [r'\bj6\b','bbb.j6'],
   [r'\bj7\b','bbb.j7'],
   [r'\bj8\b','bbb.j8'],
   [r'\bj1p\b','bbb.j1p'],
   [r'\bj2p\b','bbb.j2p'],
   [r'\bj5p\b','bbb.j5p'],
   [r'\bj6p\b','bbb.j6p'],
   [r'\bixs1\b','bbb.ixs1'],
   [r'\bixf6\b','bbb.ixf6'],
   [r'\biys1\b','bbb.iys1'],
   [r'\biyf6\b','bbb.iyf6'],
   [r'\bxlinc\b','bbb.xlinc'],
   [r'\bxrinc\b','bbb.xrinc'],
   [r'\byinc\b','bbb.yinc'],
   [r'\bisjaccorall\b','bbb.isjaccorall'],
   [r'\bixm1\b','bbb.ixm1'],
   [r'\bixp1\b','bbb.ixp1'],
   [r'\biym1a\b','bbb.iym1a'],
   [r'\biyp1a\b','bbb.iyp1a'],
   [r'\bstretcx\b','bbb.stretcx'],
   [r'\bix\b','bbb.ix'],
   [r'\biy\b','bbb.iy'],
   [r'\bigsp\b','bbb.igsp'],
   [r'\biv\b','bbb.iv'],
   [r'\biv1\b','bbb.iv1'],
   [r'\biv2\b','bbb.iv2'],
   [r'\biv3\b','bbb.iv3'],
   [r'\bix1\b','bbb.ix1'],
   [r'\bix2\b','bbb.ix2'],
   [r'\bix3\b','bbb.ix3'],
   [r'\bix4\b','bbb.ix4'],
   [r'\bix5\b','bbb.ix5'],
   [r'\bix6\b','bbb.ix6'],
   [r'\bixmp\b','bbb.ixmp'],
   [r'\btv\b','bbb.tv'],
   [r'\bt0\b','bbb.t0'],
   [r'\bt1\b','bbb.t1'],
   [r'\bt2\b','bbb.t2'],
   [r'\ba\b','bbb.a'],
   [r'\berrmsgflag\b','bbb.errmsgflag'],
   [r'\berrunit\b','bbb.errunit'],
   [r'\binopt\b','bbb.inopt'],
   [r'\biworkin\b','bbb.iworkin'],
   [r'\brworkin\b','bbb.rworkin'],
   [r'\bruntim\b','bbb.runtim'],
   [r'\btrange\b','bbb.trange'],
   [r'\bneq\b','bbb.neq'],
   [r'\bjacflg\b','bbb.jacflg'],
   [r'\bjpre\b','bbb.jpre'],
   [r'\brtolv\b','bbb.rtolv'],
   [r'\bitol\b','bbb.itol'],
   [r'\bitask\b','bbb.itask'],
   [r'\bistate\b','bbb.istate'],
   [r'\biopts\b','bbb.iopts'],
   [r'\bmf\b','bbb.mf'],
   [r'\bidid\b','bbb.idid'],
   [r'\bires\b','bbb.ires'],
   [r'\bts\b','bbb.ts'],
   [r'\btout\b','bbb.tout'],
   [r'\bdtmax\b','bbb.dtmax'],
   [r'\bdtinit\b','bbb.dtinit'],
   [r'\bmaxpoly\b','bbb.maxpoly'],
   [r'\bipar\b','bbb.ipar'],
   [r'\brpar\b','bbb.rpar'],
   [r'\brtol\b','bbb.rtol'],
   [r'\batol\b','bbb.atol'],
   [r'\byl\b','bbb.yl'],
   [r'\byldot\b','bbb.yldot'],
   [r'\bdelta\b','bbb.delta'],
   [r'\biextra\b','bbb.iextra'],
   [r'\binfo\b','bbb.info'],
   [r'\beplidpk\b','bbb.eplidpk'],
   [r'\bepnldpk\b','bbb.epnldpk'],
   [r'\bsrtolpk\b','bbb.srtolpk'],
   [r'\befacn\b','bbb.efacn'],
   [r'\bftol\b','bbb.ftol'],
   [r'\bstptol\b','bbb.stptol'],
   [r'\bepscon1\b','bbb.epscon1'],
   [r'\bepscon2\b','bbb.epscon2'],
   [r'\biterm\b','bbb.iterm'],
   [r'\bmdif\b','bbb.mdif'],
   [r'\bipflag\b','bbb.ipflag'],
   [r'\bmfnksol\b','bbb.mfnksol'],
   [r'\biprint\b','bbb.iprint'],
   [r'\bitermx\b','bbb.itermx'],
   [r'\bstepmx\b','bbb.stepmx'],
   [r'\bdel2nksol\b','bbb.del2nksol'],
   [r'\btaunksol\b','bbb.taunksol'],
   [r'\bincpset\b','bbb.incpset'],
   [r'\bismmaxuc\b','bbb.ismmaxuc'],
   [r'\bmmaxu\b','bbb.mmaxu'],
   [r'\bicntnunk\b','bbb.icntnunk'],
   [r'\bnlocal\b','bbb.nlocal'],
   [r'\bneqg\b','bbb.neqg'],
   [r'\bnxg\b','bbb.nxg'],
   [r'\bnyg\b','bbb.nyg'],
   [r'\bmeth\b','bbb.meth'],
   [r'\bitmeth\b','bbb.itmeth'],
   [r'\biatol\b','bbb.iatol'],
   [r'\bigs\b','bbb.igs'],
   [r'\bmaxkd\b','bbb.maxkd'],
   [r'\bmaxlrst\b','bbb.maxlrst'],
   [r'\bmsbpre\b','bbb.msbpre'],
   [r'\bglobalstrat\b','bbb.globalstrat'],
   [r'\biopt\b','bbb.iopt'],
   [r'\bropt\b','bbb.ropt'],
   [r'\brtol_pv\b','bbb.rtol_pv'],
   [r'\batol_pv\b','bbb.atol_pv'],
   [r'\bdelt_pv\b','bbb.delt_pv'],
   [r'\bicflag\b','bbb.icflag'],
   [r'\brlx\b','bbb.rlx'],
   [r'\brlxv\b','bbb.rlxv'],
   [r'\bicnstr\b','bbb.icnstr'],
   [r'\bconstr\b','bbb.constr'],
   [r'\bylprevc\b','bbb.ylprevc'],
   [r'\bylchng\b','bbb.ylchng'],
   [r'\badjf1\b','bbb.adjf1'],
   [r'\biscolnorm\b','bbb.iscolnorm'],
   [r'\bnorm_cons\b','bbb.norm_cons'],
   [r'\bfloor_cons\b','bbb.floor_cons'],
   [r'\bvar_scale_floor\b','bbb.var_scale_floor'],
   [r'\bvsf_up\b','bbb.vsf_up'],
   [r'\bvsf_phi\b','bbb.vsf_phi'],
   [r'\bn0\b','bbb.n0'],
   [r'\bn0g\b','bbb.n0g'],
   [r'\btemp0\b','bbb.temp0'],
   [r'\bisflxvar\b','bbb.isflxvar'],
   [r'\bisrscalf\b','bbb.isrscalf'],
   [r'\bdx0\b','bbb.dx0'],
   [r'\bnnorm\b','bbb.nnorm'],
   [r'\bennorm\b','bbb.ennorm'],
   [r'\bsigbar0\b','bbb.sigbar0'],
   [r'\bvpnorm\b','bbb.vpnorm'],
   [r'\bfnorm\b','bbb.fnorm'],
   [r'\bsuscal\b','bbb.suscal'],
   [r'\bsfscal\b','bbb.sfscal'],
   [r'\brdoff\b','bbb.rdoff'],
   [r'\byloext\b','bbb.yloext'],
   [r'\bisyloext\b','bbb.isyloext'],
   [r'\bpi\b','bbb.pi'],
   [r'\bme\b','bbb.me'],
   [r'\bmp\b','bbb.mp'],
   [r'\bev\b','bbb.ev'],
   [r'\bqe\b','bbb.qe'],
   [r'\bmu0\b','bbb.mu0'],
   [r'\beps0\b','bbb.eps0'],
   [r'\brt8opi\b','bbb.rt8opi'],
   [r'\bparvis\b','bbb.parvis'],
   [r'\btravis\b','bbb.travis'],
   [r'\bdifni\b','bbb.difni'],
   [r'\bdif4order\b','bbb.dif4order'],
   [r'\bdifgy4order\b','bbb.difgy4order'],
   [r'\bdifgx4order\b','bbb.difgx4order'],
   [r'\bdifax\b','bbb.difax'],
   [r'\bdifnit\b','bbb.difnit'],
   [r'\bcdifnit\b','bbb.cdifnit'],
   [r'\bdifpr\b','bbb.difpr'],
   [r'\bdifni2\b','bbb.difni2'],
   [r'\bdifpr2\b','bbb.difpr2'],
   [r'\bdifutm\b','bbb.difutm'],
   [r'\bdifniv\b','bbb.difniv'],
   [r'\bdifprv\b','bbb.difprv'],
   [r'\bdifniv2\b','bbb.difniv2'],
   [r'\btravisv\b','bbb.travisv'],
   [r'\bkyev\b','bbb.kyev'],
   [r'\bkyiv\b','bbb.kyiv'],
   [r'\bdifutmv\b','bbb.difutmv'],
   [r'\bvconyv\b','bbb.vconyv'],
   [r'\binbtdif\b','bbb.inbtdif'],
   [r'\binbpdif\b','bbb.inbpdif'],
   [r'\bixbpmin\b','bbb.ixbpmin'],
   [r'\bisbohmcalc\b','bbb.isbohmcalc'],
   [r'\bfacbni\b','bbb.facbni'],
   [r'\bfacbup\b','bbb.facbup'],
   [r'\bfacbni2\b','bbb.facbni2'],
   [r'\bfacbee\b','bbb.facbee'],
   [r'\bfacbei\b','bbb.facbei'],
   [r'\bvcony\b','bbb.vcony'],
   [r'\bdifcng\b','bbb.difcng'],
   [r'\bisgasdc\b','bbb.isgasdc'],
   [r'\bflalfe\b','bbb.flalfe'],
   [r'\bflalfi\b','bbb.flalfi'],
   [r'\blxtemax\b','bbb.lxtemax'],
   [r'\blxtimax\b','bbb.lxtimax'],
   [r'\blxtgmax\b','bbb.lxtgmax'],
   [r'\bflalftf\b','bbb.flalftf'],
   [r'\bflgam\b','bbb.flgam'],
   [r'\bflgamv\b','bbb.flgamv'],
   [r'\bflgamg\b','bbb.flgamg'],
   [r'\bflgamvg\b','bbb.flgamvg'],
   [r'\bflgamtg\b','bbb.flgamtg'],
   [r'\bfricflf\b','bbb.fricflf'],
   [r'\bisflxlde\b','bbb.isflxlde'],
   [r'\bisflxldi\b','bbb.isflxldi'],
   [r'\bkxe\b','bbb.kxe'],
   [r'\balfkxi\b','bbb.alfkxi'],
   [r'\balfkxe\b','bbb.alfkxe'],
   [r'\brkxecore\b','bbb.rkxecore'],
   [r'\binkxc\b','bbb.inkxc'],
   [r'\bkye\b','bbb.kye'],
   [r'\bkye4order\b','bbb.kye4order'],
   [r'\bkyet\b','bbb.kyet'],
   [r'\bckyet\b','bbb.ckyet'],
   [r'\bkxi\b','bbb.kxi'],
   [r'\bkxicore\b','bbb.kxicore'],
   [r'\bkxn\b','bbb.kxn'],
   [r'\bkyi\b','bbb.kyi'],
   [r'\bkyi4order\b','bbb.kyi4order'],
   [r'\bkyit\b','bbb.kyit'],
   [r'\bckyit\b','bbb.ckyit'],
   [r'\bkyn\b','bbb.kyn'],
   [r'\bfeqp\b','bbb.feqp'],
   [r'\balfeqp\b','bbb.alfeqp'],
   [r'\bflalfgx\b','bbb.flalfgx'],
   [r'\bflalfgy\b','bbb.flalfgy'],
   [r'\bflalfgxy\b','bbb.flalfgxy'],
   [r'\bflalfgnx\b','bbb.flalfgnx'],
   [r'\bflalfgny\b','bbb.flalfgny'],
   [r'\bgcfacgx\b','bbb.gcfacgx'],
   [r'\bgcfacgy\b','bbb.gcfacgy'],
   [r'\bgcfacgtx\b','bbb.gcfacgtx'],
   [r'\bgcfacgty\b','bbb.gcfacgty'],
   [r'\bisdifxg_aug\b','bbb.isdifxg_aug'],
   [r'\bisdifyg_aug\b','bbb.isdifyg_aug'],
   [r'\bflalfv\b','bbb.flalfv'],
   [r'\bisupdrag\b','bbb.isupdrag'],
   [r'\bcon_leng\b','bbb.con_leng'],
   [r'\bfrac_pt\b','bbb.frac_pt'],
   [r'\bflalftgx\b','bbb.flalftgx'],
   [r'\bflalftgy\b','bbb.flalftgy'],
   [r'\bflalfvgx\b','bbb.flalfvgx'],
   [r'\bflalfvgy\b','bbb.flalfvgy'],
   [r'\bflalfvgxy\b','bbb.flalfvgxy'],
   [r'\bflalftxy\b','bbb.flalftxy'],
   [r'\brnn2cx\b','bbb.rnn2cx'],
   [r'\brscat2cx\b','bbb.rscat2cx'],
   [r'\bsigcx\b','bbb.sigcx'],
   [r'\bsigcxms\b','bbb.sigcxms'],
   [r'\brcxighg\b','bbb.rcxighg'],
   [r'\bkelhihg\b','bbb.kelhihg'],
   [r'\bkelhghg\b','bbb.kelhghg'],
   [r'\bkelhmhg\b','bbb.kelhmhg'],
   [r'\bkelighi\b','bbb.kelighi'],
   [r'\bkelighg\b','bbb.kelighg'],
   [r'\bkeligii\b','bbb.keligii'],
   [r'\bkeligig\b','bbb.keligig'],
   [r'\bcfmassfac\b','bbb.cfmassfac'],
   [r'\bsigvi_floor\b','bbb.sigvi_floor'],
   [r'\bfupe_cur\b','bbb.fupe_cur'],
   [r'\bdiffusivity\b','bbb.diffusivity'],
   [r'\bdiffusivwrk\b','bbb.diffusivwrk'],
   [r'\bdiffusivloc\b','bbb.diffusivloc'],
   [r'\bcfnus_e\b','bbb.cfnus_e'],
   [r'\bcfnus_i\b','bbb.cfnus_i'],
   [r'\bcoll_fe\b','bbb.coll_fe'],
   [r'\bcoll_fi\b','bbb.coll_fi'],
   [r'\btibsep\b','bbb.tibsep'],
   [r'\btebsep\b','bbb.tebsep'],
   [r'\bcfelecbwd\b','bbb.cfelecbwd'],
   [r'\bfluxfacy\b','bbb.fluxfacy'],
   [r'\bisdifbetap\b','bbb.isdifbetap'],
   [r'\biexpbp\b','bbb.iexpbp'],
   [r'\bdfacbp\b','bbb.dfacbp'],
   [r'\btrfacbp\b','bbb.trfacbp'],
   [r'\bkefacbp\b','bbb.kefacbp'],
   [r'\bkifacbp\b','bbb.kifacbp'],
   [r'\bflalfea\b','bbb.flalfea'],
   [r'\bflalfia\b','bbb.flalfia'],
   [r'\bflalfva\b','bbb.flalfva'],
   [r'\bflalfgxa\b','bbb.flalfgxa'],
   [r'\bflalfgxya\b','bbb.flalfgxya'],
   [r'\bflalfgya\b','bbb.flalfgya'],
   [r'\bflalfvgxa\b','bbb.flalfvgxa'],
   [r'\bflalfvgxya\b','bbb.flalfvgxya'],
   [r'\bflalfvgya\b','bbb.flalfvgya'],
   [r'\bflalftgxa\b','bbb.flalftgxa'],
   [r'\bflalftgxya\b','bbb.flalftgxya'],
   [r'\bflalftgya\b','bbb.flalftgya'],
   [r'\bcfmolcool\b','bbb.cfmolcool'],
   [r'\bisdifuseinterp\b','bbb.isdifuseinterp'],
   [r'\bisadjsolprof\b','bbb.isadjsolprof'],
   [r'\bdenrdrop\b','bbb.denrdrop'],
   [r'\bterdrop\b','bbb.terdrop'],
   [r'\btirdrop\b','bbb.tirdrop'],
   [r'\bmaxchgdiff\b','bbb.maxchgdiff'],
   [r'\bdif_use_max\b','bbb.dif_use_max'],
   [r'\bdif_use_min\b','bbb.dif_use_min'],
   [r'\bkye_use_max\b','bbb.kye_use_max'],
   [r'\bkye_use_min\b','bbb.kye_use_min'],
   [r'\bkyi_use_max\b','bbb.kyi_use_max'],
   [r'\bkyi_use_min\b','bbb.kyi_use_min'],
   [r'\bdifni_sol\b','bbb.difni_sol'],
   [r'\bdifni_pf\b','bbb.difni_pf'],
   [r'\bkye_sol\b','bbb.kye_sol'],
   [r'\bkye_pf\b','bbb.kye_pf'],
   [r'\bkyi_sol\b','bbb.kyi_sol'],
   [r'\bkyi_pf\b','bbb.kyi_pf'],
   [r'\bdel_sp\b','bbb.del_sp'],
   [r'\bdel_witot\b','bbb.del_witot'],
   [r'\bdel_wetot\b','bbb.del_wetot'],
   [r'\bdel_dndt\b','bbb.del_dndt'],
   [r'\bdel_deedt\b','bbb.del_deedt'],
   [r'\bdel_deidt\b','bbb.del_deidt'],
   [r'\bdel_wicd\b','bbb.del_wicd'],
   [r'\bdel_wicv\b','bbb.del_wicv'],
   [r'\bdel_wecd\b','bbb.del_wecd'],
   [r'\bdel_wecv\b','bbb.del_wecv'],
   [r'\bdel_wicdd\b','bbb.del_wicdd'],
   [r'\bdel_wecdd\b','bbb.del_wecdd'],
   [r'\bdel_cei\b','bbb.del_cei'],
   [r'\bdel_wivdp\b','bbb.del_wivdp'],
   [r'\bdel_wevdp\b','bbb.del_wevdp'],
   [r'\bdif_int\b','bbb.dif_int'],
   [r'\bkyi_int\b','bbb.kyi_int'],
   [r'\bkye_int\b','bbb.kye_int'],
   [r'\bvyn_int\b','bbb.vyn_int'],
   [r'\bvyei_int\b','bbb.vyei_int'],
   [r'\bvyee_int\b','bbb.vyee_int'],
   [r'\bgamp\b','bbb.gamp'],
   [r'\bgamei\b','bbb.gamei'],
   [r'\bgamee\b','bbb.gamee'],
   [r'\bpfmpg\b','bbb.pfmpg'],
   [r'\bfacgam\b','bbb.facgam'],
   [r'\bfloyd\b','bbb.floyd'],
   [r'\bkappabar\b','bbb.kappabar'],
   [r'\blambdan\b','bbb.lambdan'],
   [r'\blambdat\b','bbb.lambdat'],
   [r'\bgammasi\b','bbb.gammasi'],
   [r'\blambdap\b','bbb.lambdap'],
   [r'\bsuppress_lmode\b','bbb.suppress_lmode'],
   [r'\bmaxmag_lmode\b','bbb.maxmag_lmode'],
   [r'\bnky\b','bbb.nky'],
   [r'\bkybeg\b','bbb.kybeg'],
   [r'\bkyend\b','bbb.kyend'],
   [r'\bkya\b','bbb.kya'],
   [r'\bkyb\b','bbb.kyb'],
   [r'\biprint_lmode\b','bbb.iprint_lmode'],
   [r'\btol_lmode\b','bbb.tol_lmode'],
   [r'\bisturbnloc\b','bbb.isturbnloc'],
   [r'\bisturbcons\b','bbb.isturbcons'],
   [r'\bdiffusrange\b','bbb.diffusrange'],
   [r'\bdiffuslimit\b','bbb.diffuslimit'],
   [r'\bdiffuswgts\b','bbb.diffuswgts'],
   [r'\bislmodebeta\b','bbb.islmodebeta'],
   [r'\bgradvconst\b','bbb.gradvconst'],
   [r'\bepsilon\b','bbb.epsilon'],
   [r'\bturbdelta\b','bbb.turbdelta'],
   [r'\bssqthsqavg\b','bbb.ssqthsqavg'],
   [r'\bkxconst\b','bbb.kxconst'],
   [r'\bcubrtnu\b','bbb.cubrtnu'],
   [r'\bbcoef0\b','bbb.bcoef0'],
   [r'\bccoef1\b','bbb.ccoef1'],
   [r'\bccoef2\b','bbb.ccoef2'],
   [r'\bccoef3\b','bbb.ccoef3'],
   [r'\bchinorml\b','bbb.chinorml'],
   [r'\bchinormh\b','bbb.chinormh'],
   [r'\bnsteps\b','bbb.nsteps'],
   [r'\bn_stor\b','bbb.n_stor'],
   [r'\bdt_init_rundt\b','bbb.dt_init_rundt'],
   [r'\bnist1\b','bbb.nist1'],
   [r'\bupst1\b','bbb.upst1'],
   [r'\btest1\b','bbb.test1'],
   [r'\btist1\b','bbb.tist1'],
   [r'\bngst1\b','bbb.ngst1'],
   [r'\bphist1\b','bbb.phist1'],
   [r'\btoutlsod\b','bbb.toutlsod'],
   [r'\byldnmx\b','bbb.yldnmx'],
   [r'\biyldnmx\b','bbb.iyldnmx'],
   [r'\bistep_nk\b','bbb.istep_nk'],
   [r'\bnsteps_nk\b','bbb.nsteps_nk'],
   [r'\bni_stor\b','bbb.ni_stor'],
   [r'\bup_stor\b','bbb.up_stor'],
   [r'\bte_stor\b','bbb.te_stor'],
   [r'\bti_stor\b','bbb.ti_stor'],
   [r'\bng_stor\b','bbb.ng_stor'],
   [r'\bphi_stor\b','bbb.phi_stor'],
   [r'\btim_stor\b','bbb.tim_stor'],
   [r'\bnfe_stor\b','bbb.nfe_stor'],
   [r'\bdtreal_stor\b','bbb.dtreal_stor'],
   [r'\brdtphidtr\b','bbb.rdtphidtr'],
   [r'\bismfnkauto\b','bbb.ismfnkauto'],
   [r'\bdtmfnk3\b','bbb.dtmfnk3'],
   [r'\bmult_dt\b','bbb.mult_dt'],
   [r'\bii1max\b','bbb.ii1max'],
   [r'\bii2max\b','bbb.ii2max'],
   [r'\bitermx_dt\b','bbb.itermx_dt'],
   [r'\bftol_dt\b','bbb.ftol_dt'],
   [r'\bftol_min\b','bbb.ftol_min'],
   [r'\bdt_tot\b','bbb.dt_tot'],
   [r'\bt_stop\b','bbb.t_stop'],
   [r'\bdt_max\b','bbb.dt_max'],
   [r'\bdt_kill\b','bbb.dt_kill'],
   [r'\bdeldt_min\b','bbb.deldt_min'],
   [r'\binitjac\b','bbb.initjac'],
   [r'\birev\b','bbb.irev'],
   [r'\btstor_s\b','bbb.tstor_s'],
   [r'\btstor_e\b','bbb.tstor_e'],
   [r'\bipt\b','bbb.ipt'],
   [r'\bsavefname\b','bbb.savefname'],
   [r'\biprtrundt\b','bbb.iprtrundt'],
   [r'\bmi\b','bbb.mi'],
   [r'\bzi\b','bbb.zi'],
   [r'\bmg\b','bbb.mg'],
   [r'\bfacmg\b','bbb.facmg'],
   [r'\bznucl\b','bbb.znucl'],
   [r'\bni\b','bbb.ni'],
   [r'\blni\b','bbb.lni'],
   [r'\bnm\b','bbb.nm'],
   [r'\bnz2\b','bbb.nz2'],
   [r'\buu\b','bbb.uu'],
   [r'\buup\b','bbb.uup'],
   [r'\bup\b','bbb.up'],
   [r'\bupi\b','bbb.upi'],
   [r'\bupifmb\b','bbb.upifmb'],
   [r'\buz\b','bbb.uz'],
   [r'\bv2\b','bbb.v2'],
   [r'\bv2xgp\b','bbb.v2xgp'],
   [r'\bv2ce\b','bbb.v2ce'],
   [r'\bv2cb\b','bbb.v2cb'],
   [r'\bve2cb\b','bbb.ve2cb'],
   [r'\bv2cd\b','bbb.v2cd'],
   [r'\bve2cd\b','bbb.ve2cd'],
   [r'\bq2cd\b','bbb.q2cd'],
   [r'\bv2rd\b','bbb.v2rd'],
   [r'\bv2dd\b','bbb.v2dd'],
   [r'\bvy\b','bbb.vy'],
   [r'\bvygp\b','bbb.vygp'],
   [r'\bvytan\b','bbb.vytan'],
   [r'\bvygtan\b','bbb.vygtan'],
   [r'\bvyce\b','bbb.vyce'],
   [r'\bvycb\b','bbb.vycb'],
   [r'\bveycb\b','bbb.veycb'],
   [r'\bvycp\b','bbb.vycp'],
   [r'\bveycp\b','bbb.veycp'],
   [r'\bvyrd\b','bbb.vyrd'],
   [r'\bvydd\b','bbb.vydd'],
   [r'\bvyavis\b','bbb.vyavis'],
   [r'\bvex\b','bbb.vex'],
   [r'\bupe\b','bbb.upe'],
   [r'\bvep\b','bbb.vep'],
   [r'\bve2\b','bbb.ve2'],
   [r'\bvey\b','bbb.vey'],
   [r'\bvycf\b','bbb.vycf'],
   [r'\bvycr\b','bbb.vycr'],
   [r'\bte\b','bbb.te'],
   [r'\bti\b','bbb.ti'],
   [r'\bng\b','bbb.ng'],
   [r'\blng\b','bbb.lng'],
   [r'\buug\b','bbb.uug'],
   [r'\bvyg\b','bbb.vyg'],
   [r'\btg\b','bbb.tg'],
   [r'\bistgcon\b','bbb.istgcon'],
   [r'\btev\b','bbb.tev'],
   [r'\bniv\b','bbb.niv'],
   [r'\bupv\b','bbb.upv'],
   [r'\bngv\b','bbb.ngv'],
   [r'\btiv\b','bbb.tiv'],
   [r'\bniy0\b','bbb.niy0'],
   [r'\bniy1\b','bbb.niy1'],
   [r'\bniy0s\b','bbb.niy0s'],
   [r'\bniy1s\b','bbb.niy1s'],
   [r'\bney0\b','bbb.ney0'],
   [r'\bney1\b','bbb.ney1'],
   [r'\bnity0\b','bbb.nity0'],
   [r'\bnity1\b','bbb.nity1'],
   [r'\btey0\b','bbb.tey0'],
   [r'\btey1\b','bbb.tey1'],
   [r'\btiy0\b','bbb.tiy0'],
   [r'\btiy1\b','bbb.tiy1'],
   [r'\btiy0s\b','bbb.tiy0s'],
   [r'\btiy1s\b','bbb.tiy1s'],
   [r'\btgy0\b','bbb.tgy0'],
   [r'\btgy1\b','bbb.tgy1'],
   [r'\bngy0\b','bbb.ngy0'],
   [r'\bngy1\b','bbb.ngy1'],
   [r'\bpgy0\b','bbb.pgy0'],
   [r'\bpgy1\b','bbb.pgy1'],
   [r'\bpg\b','bbb.pg'],
   [r'\bphiy0\b','bbb.phiy0'],
   [r'\bphiy1\b','bbb.phiy1'],
   [r'\bphiy0s\b','bbb.phiy0s'],
   [r'\bphiy1s\b','bbb.phiy1s'],
   [r'\bpr\b','bbb.pr'],
   [r'\bprev\b','bbb.prev'],
   [r'\bprtv\b','bbb.prtv'],
   [r'\bpri\b','bbb.pri'],
   [r'\bpriv\b','bbb.priv'],
   [r'\bpriy0\b','bbb.priy0'],
   [r'\bpriy1\b','bbb.priy1'],
   [r'\bpre\b','bbb.pre'],
   [r'\bne\b','bbb.ne'],
   [r'\bnit\b','bbb.nit'],
   [r'\bnginit\b','bbb.nginit'],
   [r'\bphi\b','bbb.phi'],
   [r'\bphiv\b','bbb.phiv'],
   [r'\bzeff\b','bbb.zeff'],
   [r'\bnetap\b','bbb.netap'],
   [r'\bznot\b','bbb.znot'],
   [r'\bzimpc\b','bbb.zimpc'],
   [r'\bnil\b','bbb.nil'],
   [r'\bupl\b','bbb.upl'],
   [r'\btel\b','bbb.tel'],
   [r'\btil\b','bbb.til'],
   [r'\bngl\b','bbb.ngl'],
   [r'\bphil\b','bbb.phil'],
   [r'\bupxpt\b','bbb.upxpt'],
   [r'\bnixpt\b','bbb.nixpt'],
   [r'\bvisyxpt\b','bbb.visyxpt'],
   [r'\bvyhxpt\b','bbb.vyhxpt'],
   [r'\bvyvxpt\b','bbb.vyvxpt'],
   [r'\bfmihxpt\b','bbb.fmihxpt'],
   [r'\bfmivxpt\b','bbb.fmivxpt'],
   [r'\brtauxfac\b','bbb.rtauxfac'],
   [r'\brtauyfac\b','bbb.rtauyfac'],
   [r'\brt_scal\b','bbb.rt_scal'],
   [r'\brtaux\b','bbb.rtaux'],
   [r'\brtauy\b','bbb.rtauy'],
   [r'\brtau\b','bbb.rtau'],
   [r'\bbetap\b','bbb.betap'],
   [r'\bfetx\b','bbb.fetx'],
   [r'\bfety\b','bbb.fety'],
   [r'\bpdrift\b','bbb.pdrift'],
   [r'\bpeirad\b','bbb.peirad'],
   [r'\bpng2ni\b','bbb.png2ni'],
   [r'\bpmomv\b','bbb.pmomv'],
   [r'\bjdote\b','bbb.jdote'],
   [r'\bengerr\b','bbb.engerr'],
   [r'\bptjdote\b','bbb.ptjdote'],
   [r'\bptigas\b','bbb.ptigas'],
   [r'\bpvmomcx\b','bbb.pvmomcx'],
   [r'\biion\b','bbb.iion'],
   [r'\birecomb\b','bbb.irecomb'],
   [r'\bicxgas\b','bbb.icxgas'],
   [r'\biion_tot\b','bbb.iion_tot'],
   [r'\birecomb_tot\b','bbb.irecomb_tot'],
   [r'\bicxgas_tot\b','bbb.icxgas_tot'],
   [r'\bpradht\b','bbb.pradht'],
   [r'\bpradiz\b','bbb.pradiz'],
   [r'\bpradrc\b','bbb.pradrc'],
   [r'\bpradimpt\b','bbb.pradimpt'],
   [r'\bpradfft\b','bbb.pradfft'],
   [r'\bpradzbind\b','bbb.pradzbind'],
   [r'\bpradimp\b','bbb.pradimp'],
   [r'\bpbinde\b','bbb.pbinde'],
   [r'\bpbindrc\b','bbb.pbindrc'],
   [r'\bprdiss\b','bbb.prdiss'],
   [r'\bpibirth\b','bbb.pibirth'],
   [r'\bpwr_plth\b','bbb.pwr_plth'],
   [r'\bpwr_pltz\b','bbb.pwr_pltz'],
   [r'\bpwr_wallh\b','bbb.pwr_wallh'],
   [r'\bpwr_wallz\b','bbb.pwr_wallz'],
   [r'\bpwr_pfwallh\b','bbb.pwr_pfwallh'],
   [r'\bpwr_pfwallz\b','bbb.pwr_pfwallz'],
   [r'\bsdelb\b','bbb.sdelb'],
   [r'\bsderb\b','bbb.sderb'],
   [r'\bsdilb\b','bbb.sdilb'],
   [r'\bsdirb\b','bbb.sdirb'],
   [r'\bsbindlb\b','bbb.sbindlb'],
   [r'\bsbindrb\b','bbb.sbindrb'],
   [r'\bsdrlb\b','bbb.sdrlb'],
   [r'\bsdrrb\b','bbb.sdrrb'],
   [r'\bsdtlb\b','bbb.sdtlb'],
   [r'\bsdtrb\b','bbb.sdtrb'],
   [r'\bgdilb\b','bbb.gdilb'],
   [r'\bgdirb\b','bbb.gdirb'],
   [r'\bengilb\b','bbb.engilb'],
   [r'\bengirb\b','bbb.engirb'],
   [r'\bgwalli\b','bbb.gwalli'],
   [r'\bengwalli\b','bbb.engwalli'],
   [r'\bswallr\b','bbb.swallr'],
   [r'\bswalli\b','bbb.swalli'],
   [r'\bswalle\b','bbb.swalle'],
   [r'\bswbind\b','bbb.swbind'],
   [r'\bswallt\b','bbb.swallt'],
   [r'\bspfwallr\b','bbb.spfwallr'],
   [r'\bpwrsore\b','bbb.pwrsore'],
   [r'\bpwrsori\b','bbb.pwrsori'],
   [r'\bvolpsor\b','bbb.volpsor'],
   [r'\bvolmsor\b','bbb.volmsor'],
   [r'\bvoljcsor\b','bbb.voljcsor'],
   [r'\bvolpsorg\b','bbb.volpsorg'],
   [r'\bpsgov_use\b','bbb.psgov_use'],
   [r'\bjcvsor\b','bbb.jcvsor'],
   [r'\bix_sjcsor\b','bbb.ix_sjcsor'],
   [r'\bix_ejcsor\b','bbb.ix_ejcsor'],
   [r'\biy_sjcsor\b','bbb.iy_sjcsor'],
   [r'\biy_ejcsor\b','bbb.iy_ejcsor'],
   [r'\bpvole\b','bbb.pvole'],
   [r'\bpvoli\b','bbb.pvoli'],
   [r'\bz0pe\b','bbb.z0pe'],
   [r'\bz0pi\b','bbb.z0pi'],
   [r'\br0pe\b','bbb.r0pe'],
   [r'\br0pi\b','bbb.r0pi'],
   [r'\bzwpe\b','bbb.zwpe'],
   [r'\bzwpi\b','bbb.zwpi'],
   [r'\brwpe\b','bbb.rwpe'],
   [r'\brwpi\b','bbb.rwpi'],
   [r'\bivolcur\b','bbb.ivolcur'],
   [r'\bmvolcur\b','bbb.mvolcur'],
   [r'\bz0ni\b','bbb.z0ni'],
   [r'\br0ni\b','bbb.r0ni'],
   [r'\bzwni\b','bbb.zwni'],
   [r'\brwni\b','bbb.rwni'],
   [r'\bz0up\b','bbb.z0up'],
   [r'\br0up\b','bbb.r0up'],
   [r'\bzwup\b','bbb.zwup'],
   [r'\brwup\b','bbb.rwup'],
   [r'\bthetarot\b','bbb.thetarot'],
   [r'\brcutmin\b','bbb.rcutmin'],
   [r'\bzcutmin\b','bbb.zcutmin'],
   [r'\beffvng\b','bbb.effvng'],
   [r'\bivolcurg\b','bbb.ivolcurg'],
   [r'\bz0ng\b','bbb.z0ng'],
   [r'\br0ng\b','bbb.r0ng'],
   [r'\bzwng\b','bbb.zwng'],
   [r'\brwng\b','bbb.rwng'],
   [r'\bb0\b','bbb.b0'],
   [r'\bb02d\b','bbb.b02d'],
   [r'\bb0old\b','bbb.b0old'],
   [r'\bb0_use\b','bbb.b0_use'],
   [r'\brbpol\b','bbb.rbpol'],
   [r'\bbtot\b','bbb.btot'],
   [r'\brbfbt\b','bbb.rbfbt'],
   [r'\brbfbt2\b','bbb.rbfbt2'],
   [r'\bcurvrby\b','bbb.curvrby'],
   [r'\bcurvrb2\b','bbb.curvrb2'],
   [r'\bgradby\b','bbb.gradby'],
   [r'\bgradb2\b','bbb.gradb2'],
   [r'\bdbm2dx\b','bbb.dbm2dx'],
   [r'\bdbm2dy\b','bbb.dbm2dy'],
   [r'\bni0\b','bbb.ni0'],
   [r'\bng0\b','bbb.ng0'],
   [r'\bte0\b','bbb.te0'],
   [r'\bti0\b','bbb.ti0'],
   [r'\bphi0\b','bbb.phi0'],
   [r'\bup0\b','bbb.up0'],
   [r'\bvy0\b','bbb.vy0'],
   [r'\bfqp\b','bbb.fqp'],
   [r'\bcfparcur\b','bbb.cfparcur'],
   [r'\bfq2\b','bbb.fq2'],
   [r'\bfqx\b','bbb.fqx'],
   [r'\bfqxb\b','bbb.fqxb'],
   [r'\bfdiaxlb\b','bbb.fdiaxlb'],
   [r'\bfdiaxrb\b','bbb.fdiaxrb'],
   [r'\bfloxebgt\b','bbb.floxebgt'],
   [r'\bfloxibgt\b','bbb.floxibgt'],
   [r'\bfqy\b','bbb.fqy'],
   [r'\bfqyb\b','bbb.fqyb'],
   [r'\bfqyn\b','bbb.fqyn'],
   [r'\bfqym\b','bbb.fqym'],
   [r'\bfqymi\b','bbb.fqymi'],
   [r'\bfqya\b','bbb.fqya'],
   [r'\bfqydt\b','bbb.fqydt'],
   [r'\bfqydti\b','bbb.fqydti'],
   [r'\bfqyao\b','bbb.fqyao'],
   [r'\bfqyae\b','bbb.fqyae'],
   [r'\bfqyai\b','bbb.fqyai'],
   [r'\bfqyd\b','bbb.fqyd'],
   [r'\bfqygp\b','bbb.fqygp'],
   [r'\bfq2d\b','bbb.fq2d'],
   [r'\bfqypneo\b','bbb.fqypneo'],
   [r'\bfq2pneo\b','bbb.fq2pneo'],
   [r'\bfqyqneo\b','bbb.fqyqneo'],
   [r'\bfq2qneo\b','bbb.fq2qneo'],
   [r'\bfnix\b','bbb.fnix'],
   [r'\bfnixcb\b','bbb.fnixcb'],
   [r'\bfniy\b','bbb.fniy'],
   [r'\bfniy4ord\b','bbb.fniy4ord'],
   [r'\bfniycb\b','bbb.fniycb'],
   [r'\bflnix\b','bbb.flnix'],
   [r'\bflniy\b','bbb.flniy'],
   [r'\bfmix\b','bbb.fmix'],
   [r'\bfmiy\b','bbb.fmiy'],
   [r'\bfmity\b','bbb.fmity'],
   [r'\bfmixy\b','bbb.fmixy'],
   [r'\bfmgx\b','bbb.fmgx'],
   [r'\bfmgy\b','bbb.fmgy'],
   [r'\bfeex\b','bbb.feex'],
   [r'\bfeey\b','bbb.feey'],
   [r'\bfeexy\b','bbb.feexy'],
   [r'\bfeey4ord\b','bbb.feey4ord'],
   [r'\bfeix\b','bbb.feix'],
   [r'\bfeiy\b','bbb.feiy'],
   [r'\bfegx\b','bbb.fegx'],
   [r'\bfegy\b','bbb.fegy'],
   [r'\bqipar\b','bbb.qipar'],
   [r'\bqgpar\b','bbb.qgpar'],
   [r'\bfniycbo\b','bbb.fniycbo'],
   [r'\bfeiycbo\b','bbb.feiycbo'],
   [r'\bfeeycbo\b','bbb.feeycbo'],
   [r'\bfeixy\b','bbb.feixy'],
   [r'\bfeiy4ord\b','bbb.feiy4ord'],
   [r'\bfngx\b','bbb.fngx'],
   [r'\bfngx4ord\b','bbb.fngx4ord'],
   [r'\bflngx\b','bbb.flngx'],
   [r'\bfngxs\b','bbb.fngxs'],
   [r'\bfngy\b','bbb.fngy'],
   [r'\bfngy4ord\b','bbb.fngy4ord'],
   [r'\bflngy\b','bbb.flngy'],
   [r'\bfngxy\b','bbb.fngxy'],
   [r'\bflngxy\b','bbb.flngxy'],
   [r'\bfngyx\b','bbb.fngyx'],
   [r'\bfnixtot\b','bbb.fnixtot'],
   [r'\bfniytot\b','bbb.fniytot'],
   [r'\bidxn\b','bbb.idxn'],
   [r'\bidxg\b','bbb.idxg'],
   [r'\bidxtg\b','bbb.idxtg'],
   [r'\bidxu\b','bbb.idxu'],
   [r'\bidxti\b','bbb.idxti'],
   [r'\bidxte\b','bbb.idxte'],
   [r'\bidxphi\b','bbb.idxphi'],
   [r'\bivfirst\b','bbb.ivfirst'],
   [r'\bigyl\b','bbb.igyl'],
   [r'\biseqalg\b','bbb.iseqalg'],
   [r'\bisvarup\b','bbb.isvarup'],
   [r'\bisvarphi\b','bbb.isvarphi'],
   [r'\bhu\b','bbb.hu'],
   [r'\bgpe\b','bbb.gpe'],
   [r'\bnpe\b','bbb.npe'],
   [r'\bnps\b','bbb.nps'],
   [r'\bnfe\b','bbb.nfe'],
   [r'\bnst\b','bbb.nst'],
   [r'\bnni\b','bbb.nni'],
   [r'\bnli\b','bbb.nli'],
   [r'\bnje\b','bbb.nje'],
   [r'\bncfn\b','bbb.ncfn'],
   [r'\bncfl\b','bbb.ncfl'],
   [r'\bnqu\b','bbb.nqu'],
   [r'\biddas\b','bbb.iddas'],
   [r'\beqmxer\b','bbb.eqmxer'],
   [r'\blacor\b','bbb.lacor'],
   [r'\blewt\b','bbb.lewt'],
   [r'\bnpsn\b','bbb.npsn'],
   [r'\bnjen\b','bbb.njen'],
   [r'\bnewbcl\b','bbb.newbcl'],
   [r'\bnewbcr\b','bbb.newbcr'],
   [r'\biskaplex\b','bbb.iskaplex'],
   [r'\biskaprex\b','bbb.iskaprex'],
   [r'\bbcee\b','bbb.bcee'],
   [r'\bbcei\b','bbb.bcei'],
   [r'\bbceew\b','bbb.bceew'],
   [r'\bbceiw\b','bbb.bceiw'],
   [r'\bbcen\b','bbb.bcen'],
   [r'\bbcenw\b','bbb.bcenw'],
   [r'\bisfdiax\b','bbb.isfdiax'],
   [r'\bcthe\b','bbb.cthe'],
   [r'\bcthi\b','bbb.cthi'],
   [r'\bsigma1\b','bbb.sigma1'],
   [r'\bcfsigm\b','bbb.cfsigm'],
   [r'\brsigpl\b','bbb.rsigpl'],
   [r'\brsigplcore\b','bbb.rsigplcore'],
   [r'\bbcel\b','bbb.bcel'],
   [r'\bbcer\b','bbb.bcer'],
   [r'\bbcil\b','bbb.bcil'],
   [r'\bbcir\b','bbb.bcir'],
   [r'\bkappal\b','bbb.kappal'],
   [r'\bkappar\b','bbb.kappar'],
   [r'\bbctype\b','bbb.bctype'],
   [r'\bphi0r\b','bbb.phi0r'],
   [r'\bphi0l\b','bbb.phi0l'],
   [r'\bcapx\b','bbb.capx'],
   [r'\bdphi_iy1\b','bbb.dphi_iy1'],
   [r'\bkincorlb\b','bbb.kincorlb'],
   [r'\bkincorrb\b','bbb.kincorrb'],
   [r'\bcfkincor\b','bbb.cfkincor'],
   [r'\bex\b','bbb.ex'],
   [r'\bey\b','bbb.ey'],
   [r'\beinduc\b','bbb.einduc'],
   [r'\bgpix\b','bbb.gpix'],
   [r'\bgpiy\b','bbb.gpiy'],
   [r'\bgpex\b','bbb.gpex'],
   [r'\bgpey\b','bbb.gpey'],
   [r'\bgprx\b','bbb.gprx'],
   [r'\bgpry\b','bbb.gpry'],
   [r'\bgtex\b','bbb.gtex'],
   [r'\bgtey\b','bbb.gtey'],
   [r'\bgtix\b','bbb.gtix'],
   [r'\bgtiy\b','bbb.gtiy'],
   [r'\bfrice\b','bbb.frice'],
   [r'\bfrici\b','bbb.frici'],
   [r'\bfricnrl\b','bbb.fricnrl'],
   [r'\bcfgti\b','bbb.cfgti'],
   [r'\bcfgte\b','bbb.cfgte'],
   [r'\bcftaud\b','bbb.cftaud'],
   [r'\bisalfecalc\b','bbb.isalfecalc'],
   [r'\bisbetaicalc\b','bbb.isbetaicalc'],
   [r'\balfe\b','bbb.alfe'],
   [r'\bbetai\b','bbb.betai'],
   [r'\bngrid\b','bbb.ngrid'],
   [r'\big\b','bbb.ig'],
   [r'\binewton\b','bbb.inewton'],
   [r'\bimeth\b','bbb.imeth'],
   [r'\bnurlx\b','bbb.nurlx'],
   [r'\bijac\b','bbb.ijac'],
   [r'\bijactot\b','bbb.ijactot'],
   [r'\bw\b','bbb.w'],
   [r'\bw0\b','bbb.w0'],
   [r'\bw1\b','bbb.w1'],
   [r'\bw2\b','bbb.w2'],
   [r'\bw3\b','bbb.w3'],
   [r'\bflox\b','bbb.flox'],
   [r'\bfloy\b','bbb.floy'],
   [r'\bconx\b','bbb.conx'],
   [r'\bcony\b','bbb.cony'],
   [r'\bfloxe\b','bbb.floxe'],
   [r'\bfloye\b','bbb.floye'],
   [r'\bfloxi\b','bbb.floxi'],
   [r'\bfloyi\b','bbb.floyi'],
   [r'\bfloxg\b','bbb.floxg'],
   [r'\bfloyg\b','bbb.floyg'],
   [r'\bfgtdx\b','bbb.fgtdx'],
   [r'\bfgtdy\b','bbb.fgtdy'],
   [r'\bconxe\b','bbb.conxe'],
   [r'\bconye\b','bbb.conye'],
   [r'\bconxi\b','bbb.conxi'],
   [r'\bconyi\b','bbb.conyi'],
   [r'\bconxg\b','bbb.conxg'],
   [r'\bconyg\b','bbb.conyg'],
   [r'\bfloxge\b','bbb.floxge'],
   [r'\bfloyge\b','bbb.floyge'],
   [r'\bconxge\b','bbb.conxge'],
   [r'\bconyge\b','bbb.conyge'],
   [r'\bvisx\b','bbb.visx'],
   [r'\bvisy\b','bbb.visy'],
   [r'\bhcxe\b','bbb.hcxe'],
   [r'\bhcye\b','bbb.hcye'],
   [r'\bhcxij\b','bbb.hcxij'],
   [r'\bhcyij\b','bbb.hcyij'],
   [r'\bhcxg\b','bbb.hcxg'],
   [r'\bhcyg\b','bbb.hcyg'],
   [r'\bhcxi\b','bbb.hcxi'],
   [r'\bhcxineo\b','bbb.hcxineo'],
   [r'\bhcyi\b','bbb.hcyi'],
   [r'\bhcxn\b','bbb.hcxn'],
   [r'\bhcyn\b','bbb.hcyn'],
   [r'\bkxbohm\b','bbb.kxbohm'],
   [r'\bkybohm\b','bbb.kybohm'],
   [r'\bvybohm\b','bbb.vybohm'],
   [r'\bdif_use\b','bbb.dif_use'],
   [r'\bdifp_use\b','bbb.difp_use'],
   [r'\bdif2_use\b','bbb.dif2_use'],
   [r'\btray_use\b','bbb.tray_use'],
   [r'\btrax_use\b','bbb.trax_use'],
   [r'\bkye_use\b','bbb.kye_use'],
   [r'\bkyi_use\b','bbb.kyi_use'],
   [r'\bkxe_use\b','bbb.kxe_use'],
   [r'\bkxi_use\b','bbb.kxi_use'],
   [r'\bdutm_use\b','bbb.dutm_use'],
   [r'\bvy_use\b','bbb.vy_use'],
   [r'\bvyup_use\b','bbb.vyup_use'],
   [r'\bvyte_use\b','bbb.vyte_use'],
   [r'\bvyti_use\b','bbb.vyti_use'],
   [r'\bfniyos_use\b','bbb.fniyos_use'],
   [r'\bfeeyosn_use\b','bbb.feeyosn_use'],
   [r'\bfeiyosn_use\b','bbb.feiyosn_use'],
   [r'\bvy_cft\b','bbb.vy_cft'],
   [r'\bvyte_cft\b','bbb.vyte_cft'],
   [r'\bvyti_cft\b','bbb.vyti_cft'],
   [r'\bnuiz\b','bbb.nuiz'],
   [r'\bnucx\b','bbb.nucx'],
   [r'\bnucxi\b','bbb.nucxi'],
   [r'\bnueli\b','bbb.nueli'],
   [r'\bnuelg\b','bbb.nuelg'],
   [r'\bnuix\b','bbb.nuix'],
   [r'\bfnuizx\b','bbb.fnuizx'],
   [r'\bfnucxx\b','bbb.fnucxx'],
   [r'\bnurc\b','bbb.nurc'],
   [r'\bnuvl\b','bbb.nuvl'],
   [r'\bcfvlh\b','bbb.cfvlh'],
   [r'\bcfvli\b','bbb.cfvli'],
   [r'\bl_parloss\b','bbb.l_parloss'],
   [r'\beqp\b','bbb.eqp'],
   [r'\beqpg\b','bbb.eqpg'],
   [r'\bengcoolm\b','bbb.engcoolm'],
   [r'\beeli\b','bbb.eeli'],
   [r'\btdiflim\b','bbb.tdiflim'],
   [r'\blmfplim\b','bbb.lmfplim'],
   [r'\beta1\b','bbb.eta1'],
   [r'\bcfeta1\b','bbb.cfeta1'],
   [r'\brtaue\b','bbb.rtaue'],
   [r'\bcfrtaue\b','bbb.cfrtaue'],
   [r'\bdclass_e\b','bbb.dclass_e'],
   [r'\bdclass_i\b','bbb.dclass_i'],
   [r'\bcfcl_e\b','bbb.cfcl_e'],
   [r'\bcfcl_i\b','bbb.cfcl_i'],
   [r'\bomgci_taui\b','bbb.omgci_taui'],
   [r'\bomgce_taue\b','bbb.omgce_taue'],
   [r'\bnuneo\b','bbb.nuneo'],
   [r'\bvisxneo\b','bbb.visxneo'],
   [r'\bvisvol_v\b','bbb.visvol_v'],
   [r'\bvisvol_q\b','bbb.visvol_q'],
   [r'\bnuii\b','bbb.nuii'],
   [r'\bnuiistar\b','bbb.nuiistar'],
   [r'\balfneo\b','bbb.alfneo'],
   [r'\bk2neo\b','bbb.k2neo'],
   [r'\bktneo\b','bbb.ktneo'],
   [r'\bsnic\b','bbb.snic'],
   [r'\bsniv\b','bbb.sniv'],
   [r'\bpsorc\b','bbb.psorc'],
   [r'\bpsor\b','bbb.psor'],
   [r'\bpsort\b','bbb.psort'],
   [r'\bpsorxrc\b','bbb.psorxrc'],
   [r'\bpsorxr\b','bbb.psorxr'],
   [r'\bpsor_tmpov\b','bbb.psor_tmpov'],
   [r'\bpsorgc\b','bbb.psorgc'],
   [r'\bpsorg\b','bbb.psorg'],
   [r'\bpsorrgc\b','bbb.psorrgc'],
   [r'\bpsorrg\b','bbb.psorrg'],
   [r'\bpsorcxgc\b','bbb.psorcxgc'],
   [r'\bpsorcxg\b','bbb.psorcxg'],
   [r'\bpsori\b','bbb.psori'],
   [r'\bpsordis\b','bbb.psordis'],
   [r'\bpsorbgg\b','bbb.psorbgg'],
   [r'\bpsorbgz\b','bbb.psorbgz'],
   [r'\berliz\b','bbb.erliz'],
   [r'\berlrc\b','bbb.erlrc'],
   [r'\bvsoreec\b','bbb.vsoreec'],
   [r'\bvsoree\b','bbb.vsoree'],
   [r'\bpwrebkg\b','bbb.pwrebkg'],
   [r'\bpwribkg\b','bbb.pwribkg'],
   [r'\bwjdote\b','bbb.wjdote'],
   [r'\bsmoc\b','bbb.smoc'],
   [r'\bsmov\b','bbb.smov'],
   [r'\bmsor\b','bbb.msor'],
   [r'\bmsorxr\b','bbb.msorxr'],
   [r'\bseec\b','bbb.seec'],
   [r'\bseev\b','bbb.seev'],
   [r'\bseic\b','bbb.seic'],
   [r'\bseiv\b','bbb.seiv'],
   [r'\bresco\b','bbb.resco'],
   [r'\bresng\b','bbb.resng'],
   [r'\breseg\b','bbb.reseg'],
   [r'\bresmo\b','bbb.resmo'],
   [r'\bresee\b','bbb.resee'],
   [r'\bresei\b','bbb.resei'],
   [r'\bresphi\b','bbb.resphi'],
   [r'\bnstra\b','bbb.nstra'],
   [r'\bnfl\b','bbb.nfl'],
   [r'\bnatmi\b','bbb.natmi'],
   [r'\bnmoli\b','bbb.nmoli'],
   [r'\bnioni\b','bbb.nioni'],
   [r'\bnxf\b','bbb.nxf'],
   [r'\bnyf\b','bbb.nyf'],
   [r'\bnmcsp\b','bbb.nmcsp'],
   [r'\bismcnon\b','bbb.ismcnon'],
   [r'\bismcnvar\b','bbb.ismcnvar'],
   [r'\beedisspl\b','bbb.eedisspl'],
   [r'\beedisspr\b','bbb.eedisspr'],
   [r'\beidisspl\b','bbb.eidisspl'],
   [r'\beidisspr\b','bbb.eidisspr'],
   [r'\bcmntgpl\b','bbb.cmntgpl'],
   [r'\bcmntgpr\b','bbb.cmntgpr'],
   [r'\bedisswo\b','bbb.edisswo'],
   [r'\bedisswi\b','bbb.edisswi'],
   [r'\bcmntgwo\b','bbb.cmntgwo'],
   [r'\bcmntgwi\b','bbb.cmntgwi'],
   [r'\bcfneutsor_ni\b','bbb.cfneutsor_ni'],
   [r'\bcfneutsor_mi\b','bbb.cfneutsor_mi'],
   [r'\bcfneutsor_ei\b','bbb.cfneutsor_ei'],
   [r'\bcfneutsor_ee\b','bbb.cfneutsor_ee'],
   [r'\bcmneutsor_ni\b','bbb.cmneutsor_ni'],
   [r'\bcmneutsor_mi\b','bbb.cmneutsor_mi'],
   [r'\bcmneutsor_ei\b','bbb.cmneutsor_ei'],
   [r'\bcmneutsor_ee\b','bbb.cmneutsor_ee'],
   [r'\bcfneutdiv\b','bbb.cfneutdiv'],
   [r'\bcfneutdiv_fng\b','bbb.cfneutdiv_fng'],
   [r'\bcfneutdiv_fmg\b','bbb.cfneutdiv_fmg'],
   [r'\bcfneutdiv_feg\b','bbb.cfneutdiv_feg'],
   [r'\bcmneutdiv\b','bbb.cmneutdiv'],
   [r'\bcmneutdiv_fng\b','bbb.cmneutdiv_fng'],
   [r'\bcmneutdiv_fmg\b','bbb.cmneutdiv_fmg'],
   [r'\bcmneutdiv_feg\b','bbb.cmneutdiv_feg'],
   [r'\bmcalpha_ng\b','bbb.mcalpha_ng'],
   [r'\bmcalpha_pg\b','bbb.mcalpha_pg'],
   [r'\bmcalpha_fng\b','bbb.mcalpha_fng'],
   [r'\bmcalpha_fmg\b','bbb.mcalpha_fmg'],
   [r'\bmcalpha_feg\b','bbb.mcalpha_feg'],
   [r'\bng_mc\b','bbb.ng_mc'],
   [r'\bng_mc_rsd\b','bbb.ng_mc_rsd'],
   [r'\bpg_mc\b','bbb.pg_mc'],
   [r'\bpg_mc_rsd\b','bbb.pg_mc_rsd'],
   [r'\bng_ue\b','bbb.ng_ue'],
   [r'\bng_ue_rsd\b','bbb.ng_ue_rsd'],
   [r'\bupg_ue\b','bbb.upg_ue'],
   [r'\bupg_ue_rsd\b','bbb.upg_ue_rsd'],
   [r'\bpg_ue\b','bbb.pg_ue'],
   [r'\bpg_ue_rsd\b','bbb.pg_ue_rsd'],
   [r'\btg_ue\b','bbb.tg_ue'],
   [r'\btg_ue_rsd\b','bbb.tg_ue_rsd'],
   [r'\bsng_ue\b','bbb.sng_ue'],
   [r'\bsmg_ue\b','bbb.smg_ue'],
   [r'\bseg_ue\b','bbb.seg_ue'],
   [r'\bjng_mc\b','bbb.jng_mc'],
   [r'\bjng_mc_rsd\b','bbb.jng_mc_rsd'],
   [r'\bjng_ue\b','bbb.jng_ue'],
   [r'\bjng_ue_rsd\b','bbb.jng_ue_rsd'],
   [r'\bvg_mc\b','bbb.vg_mc'],
   [r'\bvg_mc_rsd\b','bbb.vg_mc_rsd'],
   [r'\bvg_ue\b','bbb.vg_ue'],
   [r'\bvg_ue_rsd\b','bbb.vg_ue_rsd'],
   [r'\bfngx_mc\b','bbb.fngx_mc'],
   [r'\bfngx_mc_rsd\b','bbb.fngx_mc_rsd'],
   [r'\bfngy_mc\b','bbb.fngy_mc'],
   [r'\bfngy_mc_rsd\b','bbb.fngy_mc_rsd'],
   [r'\bfngx_ue\b','bbb.fngx_ue'],
   [r'\bfngx_ue_rsd\b','bbb.fngx_ue_rsd'],
   [r'\bfngy_ue\b','bbb.fngy_ue'],
   [r'\bfngy_ue_rsd\b','bbb.fngy_ue_rsd'],
   [r'\bfmgx_mc\b','bbb.fmgx_mc'],
   [r'\bfmgx_mc_rsd\b','bbb.fmgx_mc_rsd'],
   [r'\bfmgy_mc\b','bbb.fmgy_mc'],
   [r'\bfmgy_mc_rsd\b','bbb.fmgy_mc_rsd'],
   [r'\bfmgx_ue\b','bbb.fmgx_ue'],
   [r'\bfmgx_ue_rsd\b','bbb.fmgx_ue_rsd'],
   [r'\bfmgy_ue\b','bbb.fmgy_ue'],
   [r'\bfmgy_ue_rsd\b','bbb.fmgy_ue_rsd'],
   [r'\bfmgxy_ue\b','bbb.fmgxy_ue'],
   [r'\bfmgxy_ue_rsd\b','bbb.fmgxy_ue_rsd'],
   [r'\bjeg_mc\b','bbb.jeg_mc'],
   [r'\bjeg_mc_rsd\b','bbb.jeg_mc_rsd'],
   [r'\bjeg_ue\b','bbb.jeg_ue'],
   [r'\bjeg_ue_rsd\b','bbb.jeg_ue_rsd'],
   [r'\bfegx_mc\b','bbb.fegx_mc'],
   [r'\bfegx_mc_rsd\b','bbb.fegx_mc_rsd'],
   [r'\bfegy_mc\b','bbb.fegy_mc'],
   [r'\bfegy_mc_rsd\b','bbb.fegy_mc_rsd'],
   [r'\bfegx_ue\b','bbb.fegx_ue'],
   [r'\bfegx_ue_rsd\b','bbb.fegx_ue_rsd'],
   [r'\bfegy_ue\b','bbb.fegy_ue'],
   [r'\bfegy_ue_rsd\b','bbb.fegy_ue_rsd'],
   [r'\bstressg_mc\b','bbb.stressg_mc'],
   [r'\bstressg_mc_rsd\b','bbb.stressg_mc_rsd'],
   [r'\bstressg_ue\b','bbb.stressg_ue'],
   [r'\bstressg_ue_rsd\b','bbb.stressg_ue_rsd'],
   [r'\bpxz_mc\b','bbb.pxz_mc'],
   [r'\bpxz_mc_rsd\b','bbb.pxz_mc_rsd'],
   [r'\bmcnsor_ni\b','bbb.mcnsor_ni'],
   [r'\bmcnsor_up\b','bbb.mcnsor_up'],
   [r'\bmcnsor_te\b','bbb.mcnsor_te'],
   [r'\bmcnsor_ti\b','bbb.mcnsor_ti'],
   [r'\bmcncurr\b','bbb.mcncurr'],
   [r'\buesor_ni\b','bbb.uesor_ni'],
   [r'\buesor_up\b','bbb.uesor_up'],
   [r'\buesor_te\b','bbb.uesor_te'],
   [r'\buesor_ti\b','bbb.uesor_ti'],
   [r'\buecurr\b','bbb.uecurr'],
   [r'\bolduecurr\b','bbb.olduecurr'],
   [r'\bstrascal\b','bbb.strascal'],
   [r'\bwsor\b','bbb.wsor'],
   [r'\besor\b','bbb.esor'],
   [r'\bsni\b','bbb.sni'],
   [r'\bsmo\b','bbb.smo'],
   [r'\bsmor\b','bbb.smor'],
   [r'\bsmophi\b','bbb.smophi'],
   [r'\bsmoz\b','bbb.smoz'],
   [r'\bsee\b','bbb.see'],
   [r'\bsei\b','bbb.sei'],
   [r'\blabela\b','bbb.labela'],
   [r'\blabelm\b','bbb.labelm'],
   [r'\blabeli\b','bbb.labeli'],
   [r'\bnaf\b','bbb.naf'],
   [r'\btaf\b','bbb.taf'],
   [r'\bnmf\b','bbb.nmf'],
   [r'\btmf\b','bbb.tmf'],
   [r'\bntf\b','bbb.ntf'],
   [r'\bttf\b','bbb.ttf'],
   [r'\bfnax\b','bbb.fnax'],
   [r'\bfnmx\b','bbb.fnmx'],
   [r'\bfntx\b','bbb.fntx'],
   [r'\bfnay\b','bbb.fnay'],
   [r'\bfnmy\b','bbb.fnmy'],
   [r'\bfnty\b','bbb.fnty'],
   [r'\bfnaz\b','bbb.fnaz'],
   [r'\bfnmz\b','bbb.fnmz'],
   [r'\bfntz\b','bbb.fntz'],
   [r'\bfeay\b','bbb.feay'],
   [r'\bfemy\b','bbb.femy'],
   [r'\bfeax\b','bbb.feax'],
   [r'\bfemx\b','bbb.femx'],
   [r'\bhatm\b','bbb.hatm'],
   [r'\bhmol\b','bbb.hmol'],
   [r'\blabelmc\b','bbb.labelmc'],
   [r'\bnmc\b','bbb.nmc'],
   [r'\btmc\b','bbb.tmc'],
   [r'\bfnmcx\b','bbb.fnmcx'],
   [r'\bfnmcy\b','bbb.fnmcy'],
   [r'\bfnmcz\b','bbb.fnmcz'],
   [r'\bfemcx\b','bbb.femcx'],
   [r'\bfemcy\b','bbb.femcy'],
   [r'\bfemcz\b','bbb.femcz'],
   [r'\bv2c\b','bbb.v2c'],
   [r'\bvyc\b','bbb.vyc'],
   [r'\bupc\b','bbb.upc'],
   [r'\buuc\b','bbb.uuc'],
   [r'\butc\b','bbb.utc'],
   [r'\bvr\b','bbb.vr'],
   [r'\bvphi\b','bbb.vphi'],
   [r'\bvz\b','bbb.vz'],
   [r'\bv2tg1\b','bbb.v2tg1'],
   [r'\bvytg1\b','bbb.vytg1'],
   [r'\buptg1\b','bbb.uptg1'],
   [r'\buutg1\b','bbb.uutg1'],
   [r'\buttg1\b','bbb.uttg1'],
   [r'\bvrtg1\b','bbb.vrtg1'],
   [r'\bvphitg1\b','bbb.vphitg1'],
   [r'\bvztg1\b','bbb.vztg1'],
   [r'\bv2tg2\b','bbb.v2tg2'],
   [r'\bvytg2\b','bbb.vytg2'],
   [r'\buptg2\b','bbb.uptg2'],
   [r'\buutg2\b','bbb.uutg2'],
   [r'\buttg2\b','bbb.uttg2'],
   [r'\bvrtg2\b','bbb.vrtg2'],
   [r'\bvphitg2\b','bbb.vphitg2'],
   [r'\bvztg2\b','bbb.vztg2'],
   [r'\bextneutopt\b','bbb.extneutopt'],
   [r'\bisextneuton\b','bbb.isextneuton'],
   [r'\bextneutmeth\b','bbb.extneutmeth'],
   [r'\buedgecmd\b','bbb.uedgecmd'],
   [r'\buedgescript\b','bbb.uedgescript'],
   [r'\buedgefile\b','bbb.uedgefile'],
   [r'\buedgesave\b','bbb.uedgesave'],
   [r'\beirenecmd\b','bbb.eirenecmd'],
   [r'\beirenefile\b','bbb.eirenefile'],
   [r'\bdegas2cmd\b','bbb.degas2cmd'],
   [r'\bdegas2mpi\b','bbb.degas2mpi'],
   [r'\bdegas2file\b','bbb.degas2file'],
   [r'\bgecmd\b','bbb.gecmd'],
   [r'\bgeufile\b','bbb.geufile'],
   [r'\bgedfile\b','bbb.gedfile'],
   [r'\bbkcmd\b','bbb.bkcmd'],
   [r'\bbkufile\b','bbb.bkufile'],
   [r'\bbkdfile\b','bbb.bkdfile'],
   [r'\bdegas2outcmd\b','bbb.degas2outcmd'],
   [r'\bdegas2outscript\b','bbb.degas2outscript'],
   [r'\bdegas2outsh\b','bbb.degas2outsh'],
   [r'\bmcnflights\b','bbb.mcnflights'],
   [r'\bncsetcmd\b','bbb.ncsetcmd'],
   [r'\bncsetvar\b','bbb.ncsetvar'],
   [r'\bext_verbose\b','bbb.ext_verbose'],
   [r'\bistimecmdon\b','bbb.istimecmdon'],
   [r'\bismpicmdon\b','bbb.ismpicmdon'],
   [r'\bmpicmd\b','bbb.mpicmd'],
   [r'\bnpopt\b','bbb.npopt'],
   [r'\bnpext\b','bbb.npext'],
   [r'\brunid\b','bbb.runid'],
   [r'\bget_neutral_sources\b','bbb.get_neutral_sources'],
   [r'\bget_neutral_moments\b','bbb.get_neutral_moments'],
   [r'\bneut_output_dir\b','bbb.neut_output_dir'],
   [r'\bneut_ng_file\b','bbb.neut_ng_file'],
   [r'\bneut_pg_file\b','bbb.neut_pg_file'],
   [r'\bneut_jng1_file\b','bbb.neut_jng1_file'],
   [r'\bneut_jng2_file\b','bbb.neut_jng2_file'],
   [r'\bneut_jng3_file\b','bbb.neut_jng3_file'],
   [r'\bneut_pg11_file\b','bbb.neut_pg11_file'],
   [r'\bneut_pg22_file\b','bbb.neut_pg22_file'],
   [r'\bneut_pg33_file\b','bbb.neut_pg33_file'],
   [r'\bneut_pg23_file\b','bbb.neut_pg23_file'],
   [r'\bneut_pg31_file\b','bbb.neut_pg31_file'],
   [r'\bneut_pg12_file\b','bbb.neut_pg12_file'],
   [r'\bneut_jeg1_file\b','bbb.neut_jeg1_file'],
   [r'\bneut_jeg2_file\b','bbb.neut_jeg2_file'],
   [r'\bneut_jeg3_file\b','bbb.neut_jeg3_file'],
   [r'\bpnc_verbose\b','bbb.pnc_verbose'],
   [r'\bpnc_opt\b','bbb.pnc_opt'],
   [r'\bpnc_step\b','bbb.pnc_step'],
   [r'\bpnc_maxstep\b','bbb.pnc_maxstep'],
   [r'\bpnc_time\b','bbb.pnc_time'],
   [r'\bdtneut\b','bbb.dtneut'],
   [r'\bdtplasma\b','bbb.dtplasma'],
   [r'\bdtold\b','bbb.dtold'],
   [r'\brelax_p\b','bbb.relax_p'],
   [r'\brelax_g\b','bbb.relax_g'],
   [r'\bpnc_ngs_mc\b','bbb.pnc_ngs_mc'],
   [r'\bpnc_upgs_mc\b','bbb.pnc_upgs_mc'],
   [r'\bpnc_tgs_mc\b','bbb.pnc_tgs_mc'],
   [r'\bpnc_histfile\b','bbb.pnc_histfile'],
   [r'\bpnc_fp\b','bbb.pnc_fp'],
   [r'\bpnc_print_norm\b','bbb.pnc_print_norm'],
   [r'\bpnc_nsave\b','bbb.pnc_nsave'],
   [r'\bpnc_savefile\b','bbb.pnc_savefile'],
   [r'\bpnc_dobalance\b','bbb.pnc_dobalance'],
   [r'\bpnc_balancefile\b','bbb.pnc_balancefile'],
   [r'\bpnc_cfparvis\b','bbb.pnc_cfparvis'],
   [r'\bpnc_cftravis\b','bbb.pnc_cftravis'],
   [r'\bpnc_cfni\b','bbb.pnc_cfni'],
   [r'\bpnc_cfup\b','bbb.pnc_cfup'],
   [r'\bni_pnc\b','bbb.ni_pnc'],
   [r'\bup_pnc\b','bbb.up_pnc'],
   [r'\bti_pnc\b','bbb.ti_pnc'],
   [r'\bte_pnc\b','bbb.te_pnc'],
   [r'\bphi_pnc\b','bbb.phi_pnc'],
   [r'\bng_pnc\b','bbb.ng_pnc'],
   [r'\bupg_pnc\b','bbb.upg_pnc'],
   [r'\btg_pnc\b','bbb.tg_pnc'],
   [r'\bsng_pnc\b','bbb.sng_pnc'],
   [r'\bsmg_pnc\b','bbb.smg_pnc'],
   [r'\bseg_pnc\b','bbb.seg_pnc'],
   [r'\bsni_pnc\b','bbb.sni_pnc'],
   [r'\bsmor_pnc\b','bbb.smor_pnc'],
   [r'\bsmophi_pnc\b','bbb.smophi_pnc'],
   [r'\bsmoz_pnc\b','bbb.smoz_pnc'],
   [r'\bsei_pnc\b','bbb.sei_pnc'],
   [r'\bsee_pnc\b','bbb.see_pnc'],
   [r'\bres_ni\b','bbb.res_ni'],
   [r'\bres_up\b','bbb.res_up'],
   [r'\bres_ti\b','bbb.res_ti'],
   [r'\bres_te\b','bbb.res_te'],
   [r'\bres_phi\b','bbb.res_phi'],
   [r'\bres_ng\b','bbb.res_ng'],
   [r'\bres_upg\b','bbb.res_upg'],
   [r'\bres_tg\b','bbb.res_tg'],
   [r'\bres_sng\b','bbb.res_sng'],
   [r'\bres_smg\b','bbb.res_smg'],
   [r'\bres_seg\b','bbb.res_seg'],
   [r'\bres_sni\b','bbb.res_sni'],
   [r'\bres_smor\b','bbb.res_smor'],
   [r'\bres_smophi\b','bbb.res_smophi'],
   [r'\bres_smoz\b','bbb.res_smoz'],
   [r'\bres_sei\b','bbb.res_sei'],
   [r'\bres_see\b','bbb.res_see'],
   [r'\bdel_ni\b','bbb.del_ni'],
   [r'\bdel_up\b','bbb.del_up'],
   [r'\bdel_ti\b','bbb.del_ti'],
   [r'\bdel_te\b','bbb.del_te'],
   [r'\bdel_phi\b','bbb.del_phi'],
   [r'\bdel_ng\b','bbb.del_ng'],
   [r'\bdel_upg\b','bbb.del_upg'],
   [r'\bdel_tg\b','bbb.del_tg'],
   [r'\bdel_sng\b','bbb.del_sng'],
   [r'\bdel_smg\b','bbb.del_smg'],
   [r'\bdel_seg\b','bbb.del_seg'],
   [r'\bdel_sni\b','bbb.del_sni'],
   [r'\bdel_smor\b','bbb.del_smor'],
   [r'\bdel_smophi\b','bbb.del_smophi'],
   [r'\bdel_smoz\b','bbb.del_smoz'],
   [r'\bdel_sei\b','bbb.del_sei'],
   [r'\bdel_see\b','bbb.del_see'],
   [r'\bpsorold\b','bbb.psorold'],
   [r'\bpsorxrold\b','bbb.psorxrold'],
   [r'\bmsorold\b','bbb.msorold'],
   [r'\bmsorxrold\b','bbb.msorxrold'],
   [r'\bylodt\b','bbb.ylodt'],
   [r'\bnufak\b','bbb.nufak'],
   [r'\bnufak0\b','bbb.nufak0'],
   [r'\binufaknk\b','bbb.inufaknk'],
   [r'\bdtreal\b','bbb.dtreal'],
   [r'\bdtdamp\b','bbb.dtdamp'],
   [r'\bitdamp\b','bbb.itdamp'],
   [r'\bdtreal_old\b','bbb.dtreal_old'],
   [r'\bdtphi\b','bbb.dtphi'],
   [r'\bydt_max\b','bbb.ydt_max'],
   [r'\bydt_max0\b','bbb.ydt_max0'],
   [r'\balfnuf\b','bbb.alfnuf'],
   [r'\bexpnuf\b','bbb.expnuf'],
   [r'\bdeldt\b','bbb.deldt'],
   [r'\bdtoptx\b','bbb.dtoptx'],
   [r'\bdtoptv\b','bbb.dtoptv'],
   [r'\bdtuse\b','bbb.dtuse'],
   [r'\bmodel_dt\b','bbb.model_dt'],
   [r'\bubw\b','bbb.ubw'],
   [r'\blbw\b','bbb.lbw'],
   [r'\brconds\b','bbb.rconds'],
   [r'\bneqp1\b','bbb.neqp1'],
   [r'\bnnzmx\b','bbb.nnzmx'],
   [r'\bjac\b','bbb.jac'],
   [r'\bjaci\b','bbb.jaci'],
   [r'\bjacj\b','bbb.jacj'],
   [r'\bisjacstnlon\b','bbb.isjacstnlon'],
   [r'\brcsc\b','bbb.rcsc'],
   [r'\bjcsc\b','bbb.jcsc'],
   [r'\bicsc\b','bbb.icsc'],
   [r'\byldot_pert\b','bbb.yldot_pert'],
   [r'\byldot_unpt\b','bbb.yldot_unpt'],
   [r'\bnnz1mx\b','bbb.nnz1mx'],
   [r'\bjac1\b','bbb.jac1'],
   [r'\bia1\b','bbb.ia1'],
   [r'\bja1\b','bbb.ja1'],
   [r'\bperm\b','bbb.perm'],
   [r'\bqperm\b','bbb.qperm'],
   [r'\blevels\b','bbb.levels'],
   [r'\bnlev\b','bbb.nlev'],
   [r'\bmask\b','bbb.mask'],
   [r'\bmaskval\b','bbb.maskval'],
   [r'\bireorder\b','bbb.ireorder'],
   [r'\bjacfull\b','bbb.jacfull'],
   [r'\bpremeth\b','bbb.premeth'],
   [r'\blenpfac\b','bbb.lenpfac'],
   [r'\blenplufac\b','bbb.lenplufac'],
   [r'\blenplumx\b','bbb.lenplumx'],
   [r'\btolilut\b','bbb.tolilut'],
   [r'\blfililut\b','bbb.lfililut'],
   [r'\bndiagmx\b','bbb.ndiagmx'],
   [r'\bndiag\b','bbb.ndiag'],
   [r'\blfilinel\b','bbb.lfilinel'],
   [r'\bndiagm\b','bbb.ndiagm'],
   [r'\badiag\b','bbb.adiag'],
   [r'\bsiginel\b','bbb.siginel'],
   [r'\bfmuinel\b','bbb.fmuinel'],
   [r'\brwkd\b','bbb.rwkd'],
   [r'\biwkd1\b','bbb.iwkd1'],
   [r'\biwkd2\b','bbb.iwkd2'],
   [r'\bnewgeo\b','bbb.newgeo'],
   [r'\bmhdgeo\b','bbb.mhdgeo'],
   [r'\bgengrid\b','bbb.gengrid'],
   [r'\bisgindx\b','bbb.isgindx'],
   [r'\bnfmax\b','bbb.nfmax'],
   [r'\brestart\b','bbb.restart'],
   [r'\binitsol\b','bbb.initsol'],
   [r'\bttbeg\b','bbb.ttbeg'],
   [r'\btinit\b','bbb.tinit'],
   [r'\btscal\b','bbb.tscal'],
   [r'\bngscal\b','bbb.ngscal'],
   [r'\bxgscal\b','bbb.xgscal'],
   [r'\bnibeg\b','bbb.nibeg'],
   [r'\bminu\b','bbb.minu'],
   [r'\bziin\b','bbb.ziin'],
   [r'\bznuclin\b','bbb.znuclin'],
   [r'\bisallloc\b','bbb.isallloc'],
   [r'\bnewaph\b','bbb.newaph'],
   [r'\bnewapi\b','bbb.newapi'],
   [r'\bpyrestart_file\b','bbb.pyrestart_file'],
   [r'\bread_diffs\b','bbb.read_diffs'],
   [r'\bdif_io\b','bbb.dif_io'],
   [r'\btra_io\b','bbb.tra_io'],
   [r'\bdutm_io\b','bbb.dutm_io'],
   [r'\bkye_io\b','bbb.kye_io'],
   [r'\bkyi_io\b','bbb.kyi_io'],
   [r'\bvy_io\b','bbb.vy_io'],
   [r'\bvyup_io\b','bbb.vyup_io'],
   [r'\bvyte_io\b','bbb.vyte_io'],
   [r'\bvyti_io\b','bbb.vyti_io'],
   [r'\bfniyos_io\b','bbb.fniyos_io'],
   [r'\bfeeyosn_io\b','bbb.feeyosn_io'],
   [r'\bfeiyosn_io\b','bbb.feiyosn_io'],
   [r'\bisvolsorext\b','bbb.isvolsorext'],
   [r'\buedge_savefile\b','bbb.uedge_savefile'],
   [r'\bisnintp\b','bbb.isnintp'],
   [r'\bisimesh\b','bbb.isimesh'],
   [r'\bisumesh2\b','bbb.isumesh2'],
   [r'\bnxold\b','bbb.nxold'],
   [r'\bnyold\b','bbb.nyold'],
   [r'\bnxoldg\b','bbb.nxoldg'],
   [r'\bnyoldg\b','bbb.nyoldg'],
   [r'\bixlbo\b','bbb.ixlbo'],
   [r'\bixpt1o\b','bbb.ixpt1o'],
   [r'\bixpt2o\b','bbb.ixpt2o'],
   [r'\bixrbo\b','bbb.ixrbo'],
   [r'\biysptrxo\b','bbb.iysptrxo'],
   [r'\bxnrmo\b','bbb.xnrmo'],
   [r'\bxvnrmo\b','bbb.xvnrmo'],
   [r'\bxnrmox\b','bbb.xnrmox'],
   [r'\bxvnrmox\b','bbb.xvnrmox'],
   [r'\bxnrmnx\b','bbb.xnrmnx'],
   [r'\bxvnrmnx\b','bbb.xvnrmnx'],
   [r'\bynrmo\b','bbb.ynrmo'],
   [r'\byvnrmo\b','bbb.yvnrmo'],
   [r'\bynrmox\b','bbb.ynrmox'],
   [r'\byvnrmox\b','bbb.yvnrmox'],
   [r'\bynrmnx\b','bbb.ynrmnx'],
   [r'\byvnrmnx\b','bbb.yvnrmnx'],
   [r'\bwrkint\b','bbb.wrkint'],
   [r'\bwrkint2\b','bbb.wrkint2'],
   [r'\bixmg\b','bbb.ixmg'],
   [r'\biyomg\b','bbb.iyomg'],
   [r'\bixvmg\b','bbb.ixvmg'],
   [r'\biyvomg\b','bbb.iyvomg'],
   [r'\bix2g\b','bbb.ix2g'],
   [r'\biy2g\b','bbb.iy2g'],
   [r'\bixv2g\b','bbb.ixv2g'],
   [r'\biyv2g\b','bbb.iyv2g'],
   [r'\bnis\b','bbb.nis'],
   [r'\btes\b','bbb.tes'],
   [r'\btis\b','bbb.tis'],
   [r'\btgs\b','bbb.tgs'],
   [r'\bphis\b','bbb.phis'],
   [r'\bups\b','bbb.ups'],
   [r'\bngs\b','bbb.ngs'],
   [r'\bafracs\b','bbb.afracs'],
   [r'\bnisg\b','bbb.nisg'],
   [r'\btesg\b','bbb.tesg'],
   [r'\btisg\b','bbb.tisg'],
   [r'\btgsg\b','bbb.tgsg'],
   [r'\bphisg\b','bbb.phisg'],
   [r'\bupsg\b','bbb.upsg'],
   [r'\bngsg\b','bbb.ngsg'],
   [r'\bafracsg\b','bbb.afracsg'],
   [r'\bipassin\b','bbb.ipassin'],
   [r'\brpassin\b','bbb.rpassin'],
   [r'\bcpassin\b','bbb.cpassin'],
   [r'\bnpes\b','bbb.npes'],
   [r'\bmype\b','bbb.mype'],
   [r'\bismpion\b','bbb.ismpion'],
   [r'\bhascomm\b','bbb.hascomm'],
   [r'\bisparmultdt\b','bbb.isparmultdt'],
   [r'\bisddcon\b','bbb.isddcon'],
   [r'\bndleg\b','bbb.ndleg'],
   [r'\bndxcore\b','bbb.ndxcore'],
   [r'\bndycore\b','bbb.ndycore'],
   [r'\bndysol\b','bbb.ndysol'],
   [r'\bidxpt\b','bbb.idxpt'],
   [r'\bndxt\b','bbb.ndxt'],
   [r'\bndyt\b','bbb.ndyt'],
   [r'\bndomain\b','bbb.ndomain'],
   [r'\bndomain_orig\b','bbb.ndomain_orig'],
   [r'\bnvrsend\b','bbb.nvrsend'],
   [r'\bnvisend\b','bbb.nvisend'],
   [r'\bixmin\b','bbb.ixmin'],
   [r'\bixmax\b','bbb.ixmax'],
   [r'\biymin\b','bbb.iymin'],
   [r'\biymax\b','bbb.iymax'],
   [r'\bixmnbcg\b','bbb.ixmnbcg'],
   [r'\bixmxbcg\b','bbb.ixmxbcg'],
   [r'\biymnbcg\b','bbb.iymnbcg'],
   [r'\biymxbcg\b','bbb.iymxbcg'],
   [r'\bncell\b','bbb.ncell'],
   [r'\bidxp1g\b','bbb.idxp1g'],
   [r'\bidxm1g\b','bbb.idxm1g'],
   [r'\bidyp1g\b','bbb.idyp1g'],
   [r'\bidym1g\b','bbb.idym1g'],
   [r'\bidcorng\b','bbb.idcorng'],
   [r'\bixpt1g\b','bbb.ixpt1g'],
   [r'\bixpt2g\b','bbb.ixpt2g'],
   [r'\biysptrxg\b','bbb.iysptrxg'],
   [r'\bvrsend\b','bbb.vrsend'],
   [r'\bvisend\b','bbb.visend'],
   [r'\bneq_locg\b','bbb.neq_locg'],
   [r'\bneq_locgmx\b','bbb.neq_locgmx'],
   [r'\bispwrbc\b','bbb.ispwrbc'],
   [r'\bivcum\b','bbb.ivcum'],
   [r'\bivloc2sdg\b','bbb.ivloc2sdg'],
   [r'\bivloc2mdg\b','bbb.ivloc2mdg'],
   [r'\bivl2gstnl\b','bbb.ivl2gstnl'],
   [r'\biellast\b','bbb.iellast'],
   [r'\bnx_loc\b','bbb.nx_loc'],
   [r'\bny_loc\b','bbb.ny_loc'],
   [r'\bnvrsendl\b','bbb.nvrsendl'],
   [r'\bnvisendl\b','bbb.nvisendl'],
   [r'\bixmnbcl\b','bbb.ixmnbcl'],
   [r'\bixmxbcl\b','bbb.ixmxbcl'],
   [r'\biymnbcl\b','bbb.iymnbcl'],
   [r'\biymxbcl\b','bbb.iymxbcl'],
   [r'\bidxp1\b','bbb.idxp1'],
   [r'\bidxm1\b','bbb.idxm1'],
   [r'\bidyp1\b','bbb.idyp1'],
   [r'\bidym1\b','bbb.idym1'],
   [r'\bidcorn\b','bbb.idcorn'],
   [r'\biv_totbdy\b','bbb.iv_totbdy'],
   [r'\btypebdyi\b','bbb.typebdyi'],
   [r'\btypecni\b','bbb.typecni'],
   [r'\btypebdy\b','bbb.typebdy'],
   [r'\btypecn\b','bbb.typecn'],
   [r'\bvrsendl\b','bbb.vrsendl'],
   [r'\bvisendl\b','bbb.visendl'],
   [r'\bneq_locl\b','bbb.neq_locl'],
   [r'\bnumvarl\b','bbb.numvarl'],
   [r'\bivloc2sdgl\b','bbb.ivloc2sdgl'],
   [r'\bivloc2mdgl\b','bbb.ivloc2mdgl'],
   [r'\bivl2gstnll\b','bbb.ivl2gstnll'],
   [r'\bispwrbcl\b','bbb.ispwrbcl'],
   [r'\bixpt1l\b','bbb.ixpt1l'],
   [r'\bixpt2l\b','bbb.ixpt2l'],
   [r'\biysptrx1l\b','bbb.iysptrx1l'],
   [r'\bixlbl\b','bbb.ixlbl'],
   [r'\bixrbl\b','bbb.ixrbl'],
   [r'\bscrit\b','bbb.scrit'],
   [r'\bylold\b','bbb.ylold'],
   [r'\byldot1\b','bbb.yldot1'],
   [r'\byldot0\b','bbb.yldot0'],
   [r'\bnormtype\b','bbb.normtype'],
   [r'\bfnormnw\b','bbb.fnormnw'],
   [r'\bissfon\b','bbb.issfon'],
   [r'\bisrnorm\b','bbb.isrnorm'],
   [r'\bjscalcol\b','bbb.jscalcol'],
   [r'\bdel\b','bbb.del'],
   [r'\bdelpy\b','bbb.delpy'],
   [r'\bdylconst\b','bbb.dylconst'],
   [r'\bisjacreset\b','bbb.isjacreset'],
   [r'\bjaccliplim\b','bbb.jaccliplim'],
   [r'\bistopjac\b','bbb.istopjac'],
   [r'\birstop\b','bbb.irstop'],
   [r'\bicstop\b','bbb.icstop'],
   [r'\bicsum\b','bbb.icsum'],
   [r'\brwmin\b','bbb.rwmin'],
   [r'\bsaux\b','bbb.saux'],
   [r'\bsaux1\b','bbb.saux1'],
   [r'\bsumnew\b','bbb.sumnew'],
   [r'\bsumrdy\b','bbb.sumrdy'],
   [r'\bnmaxnewt\b','bbb.nmaxnewt'],
   [r'\bysave\b','bbb.ysave'],
   [r'\bycor\b','bbb.ycor'],
   [r'\bsaux2\b','bbb.saux2'],
   [r'\bsumf\b','bbb.sumf'],
   [r'\birwd\b','bbb.irwd'],
   [r'\brwdmax\b','bbb.rwdmax'],
   [r'\brwdmin\b','bbb.rwdmin'],
   [r'\bsumnew1\b','bbb.sumnew1'],
   [r'\bsumr1dy\b','bbb.sumr1dy'],
   [r'\bifexmain\b','bbb.ifexmain'],
   [r'\biallcall\b','bbb.iallcall'],
   [r'\brcn\b','bbb.rcn'],
   [r'\bzcn\b','bbb.zcn'],
   [r'\brfn\b','bbb.rfn'],
   [r'\bzfn\b','bbb.zfn'],
   [r'\brcv\b','bbb.rcv'],
   [r'\bzcv\b','bbb.zcv'],
   [r'\brfv\b','bbb.rfv'],
   [r'\bzfv\b','bbb.zfv'],
   [r'\bisimpon\b','bbb.isimpon'],
   [r'\bnusp_imp\b','bbb.nusp_imp'],
   [r'\bisupimpap\b','bbb.isupimpap'],
   [r'\bismctab\b','bbb.ismctab'],
   [r'\bnzloc\b','bbb.nzloc'],
   [r'\bimpradloc\b','bbb.impradloc'],
   [r'\bpwrzec\b','bbb.pwrzec'],
   [r'\bpwrze\b','bbb.pwrze'],
   [r'\bpradc\b','bbb.pradc'],
   [r'\bpradcff\b','bbb.pradcff'],
   [r'\bprad\b','bbb.prad'],
   [r'\bpradzc\b','bbb.pradzc'],
   [r'\bpradz\b','bbb.pradz'],
   [r'\bna\b','bbb.na'],
   [r'\bntau\b','bbb.ntau'],
   [r'\bnratio\b','bbb.nratio'],
   [r'\bafrac\b','bbb.afrac'],
   [r'\batau\b','bbb.atau'],
   [r'\btau1\b','bbb.tau1'],
   [r'\btau2\b','bbb.tau2'],
   [r'\bfnzysi\b','bbb.fnzysi'],
   [r'\bfnzyso\b','bbb.fnzyso'],
   [r'\bmisotope\b','bbb.misotope'],
   [r'\bnchstate\b','bbb.nchstate'],
   [r'\bnatomic\b','bbb.natomic'],
   [r'\bamu\b','bbb.amu'],
   [r'\btempa\b','bbb.tempa'],
   [r'\bqneut\b','bbb.qneut'],
   [r'\buneut\b','bbb.uneut'],
   [r'\bden\b','bbb.den'],
   [r'\bgradp\b','bbb.gradp'],
   [r'\bgradt\b','bbb.gradt'],
   [r'\bfriction\b','bbb.friction'],
   [r'\bfriccomp\b','bbb.friccomp'],
   [r'\bnuion\b','bbb.nuion'],
   [r'\bnurec\b','bbb.nurec'],
   [r'\bqcond\b','bbb.qcond'],
   [r'\bucond\b','bbb.ucond'],
   [r'\bdztot\b','bbb.dztot'],
   [r'\bib_idiv\b','bbb.ib_idiv'],
   [r'\bie_idiv\b','bbb.ie_idiv'],
   [r'\bib_comwall\b','bbb.ib_comwall'],
   [r'\bie_comwall\b','bbb.ie_comwall'],
   [r'\bib_odiv\b','bbb.ib_odiv'],
   [r'\bie_odiv\b','bbb.ie_odiv'],
   [r'\bib_opfwall\b','bbb.ib_opfwall'],
   [r'\bie_opfwall\b','bbb.ie_opfwall'],
   [r'\bib_ipfwall\b','bbb.ib_ipfwall'],
   [r'\bie_ipfwall\b','bbb.ie_ipfwall'],
   [r'\bliw\b','bbb.liw'],
   [r'\blrw\b','bbb.lrw'],
   [r'\biwork\b','bbb.iwork'],
   [r'\brwork\b','bbb.rwork'],
   [r'\bliwp\b','bbb.liwp'],
   [r'\blwp\b','bbb.lwp'],
   [r'\biwwp\b','bbb.iwwp'],
   [r'\bwwp\b','bbb.wwp'],
   [r'\brwk1\b','bbb.rwk1'],
   [r'\brwk2\b','bbb.rwk2'],
   [r'\biwk1\b','bbb.iwk1'],
   [r'\biwk2\b','bbb.iwk2'],
   [r'\biwk3\b','bbb.iwk3'],
   [r'\bnezag\b','bbb.nezag'],
   [r'\bnizag\b','bbb.nizag'],
   [r'\btezag\b','bbb.tezag'],
   [r'\btizag\b','bbb.tizag'],
   [r'\bvizag\b','bbb.vizag'],
   [r'\buizag\b','bbb.uizag'],
   [r'\bv0zag\b','bbb.v0zag'],
   [r'\bu0zag\b','bbb.u0zag'],
   [r'\bzeffzag\b','bbb.zeffzag'],
   [r'\belfzag\b','bbb.elfzag'],
   [r'\bvezag\b','bbb.vezag'],
   [r'\buezag\b','bbb.uezag'],
   [r'\bcurxzag\b','bbb.curxzag'],
   [r'\bcuryzag\b','bbb.curyzag'],
   [r'\bt0zag\b','bbb.t0zag'],
   [r'\bn0zag\b','bbb.n0zag'],
   [r'\btz0zag\b','bbb.tz0zag'],
   [r'\bnzzag\b','bbb.nzzag'],
   [r'\bvzzag\b','bbb.vzzag'],
   [r'\buzzag\b','bbb.uzzag'],
   [r'\brxzag\b','bbb.rxzag'],
   [r'\bryzag\b','bbb.ryzag'],
   [r'\bggzag\b','bbb.ggzag'],
   [r'\bbratiozag\b','bbb.bratiozag'],
   [r'\bviparzag\b','bbb.viparzag'],
   [r'\bveparzag\b','bbb.veparzag'],
   [r'\bvzparzag\b','bbb.vzparzag'],
   [r'\bxpzag\b','bbb.xpzag'],
   [r'\bxszag\b','bbb.xszag'],
   [r'\bxkzag\b','bbb.xkzag'],
   [r'\bypzag\b','bbb.ypzag'],
   [r'\bykzag\b','bbb.ykzag'],
   [r'\bxzag\b','bbb.xzag'],
   [r'\byzag\b','bbb.yzag'],
   [r'\binh\b','bbb.inh'],
   [r'\binz\b','bbb.inz'],
   [r'\bihf\b','bbb.ihf'],
   [r'\bistype\b','bbb.istype'],
   [r'\bibound\b','bbb.ibound'],
   [r'\biboundz\b','bbb.iboundz'],
   [r'\bzs\b','bbb.zs'],
   [r'\bspuff\b','bbb.spuff'],
   [r'\blst\b','bbb.lst'],
   [r'\bwx\b','bbb.wx'],
   [r'\bwy\b','bbb.wy'],
   [r'\bht\b','bbb.ht'],
   [r'\brmach\b','bbb.rmach'],
   [r'\brecyc\b','bbb.recyc'],
   [r'\bzrecyc\b','bbb.zrecyc'],
   [r'\bimap\b','bbb.imap'],
   [r'\bsnz\b','bbb.snz'],
   [r'\bsn\b','bbb.sn'],
   [r'\bsqe\b','bbb.sqe'],
   [r'\bsqi\b','bbb.sqi'],
   [r'\bfe\b','bbb.fe'],
   [r'\bfi\b','bbb.fi'],
   [r'\bfe0\b','bbb.fe0'],
   [r'\bfi0\b','bbb.fi0'],
   [r'\bflime\b','bbb.flime'],
   [r'\bflimi\b','bbb.flimi'],
   [r'\bwkr\b','bbb.wkr'],
   [r'\bxsi\b','bbb.xsi'],
   [r'\bzxsi\b','bbb.zxsi'],
   [r'\bsdod\b','bbb.sdod'],
   [r'\byielh\b','bbb.yielh'],
   [r'\byielz\b','bbb.yielz'],
   [r'\buedge_ver\b','bbb.uedge_ver'],
   [r'\buedge_date\b','bbb.uedge_date'],
   [r'\blogfname\b','bbb.logfname'],
   [r'\bnxx\b','bbb.nxx'],
   [r'\balfz\b','bbb.alfz'],
   [r'\bvrfac\b','bbb.vrfac'],
   [r'\bsp\b','bbb.sp'],
   [r'\bcourant\b','bbb.courant'],
   [r'\btend\b','bbb.tend'],
   [r'\bndtmax\b','bbb.ndtmax'],
   [r'\bntim\b','bbb.ntim'],
   [r'\bito\b','bbb.ito'],
   [r'\bxcz\b','bbb.xcz'],
   [r'\bxfz\b','bbb.xfz'],
   [r'\bvrz\b','bbb.vrz'],
   [r'\bdrz\b','bbb.drz'],
   [r'\bdens\b','bbb.dens'],
   [r'\bvrhs\b','bbb.vrhs'],
   [r'\bdrhs\b','bbb.drhs'],
   [r'\bgampz\b','bbb.gampz'],
   [r'\bgampzt\b','bbb.gampzt'],
   [r'\bnnt\b','bbb.nnt'],
   [r'\btimo\b','bbb.timo'],
   [r'\bidim\b','grd.idim'],
   [r'\bnix\b','grd.nix'],
   [r'\bmseg\b','grd.mseg'],
   [r'\bnalpha\b','grd.nalpha'],
   [r'\bnxuse\b','grd.nxuse'],
   [r'\bnptmp\b','grd.nptmp'],
   [r'\bndata\b','grd.ndata'],
   [r'\bnbkpt\b','grd.nbkpt'],
   [r'\bnconst\b','grd.nconst'],
   [r'\bnwdim\b','grd.nwdim'],
   [r'\bniwdim\b','grd.niwdim'],
   [r'\bradm\b','grd.radm'],
   [r'\bradx\b','grd.radx'],
   [r'\brad0\b','grd.rad0'],
   [r'\brscalcore\b','grd.rscalcore'],
   [r'\bza0\b','grd.za0'],
   [r'\bzax\b','grd.zax'],
   [r'\bzaxpt\b','grd.zaxpt'],
   [r'\btiltang\b','grd.tiltang'],
   [r'\bixsnog\b','grd.ixsnog'],
   [r'\bzxpt_reset\b','grd.zxpt_reset'],
   [r'\balfyt\b','grd.alfyt'],
   [r'\btnoty\b','grd.tnoty'],
   [r'\bsratiopf\b','grd.sratiopf'],
   [r'\balfxt\b','grd.alfxt'],
   [r'\bisadjalfxt\b','grd.isadjalfxt'],
   [r'\btctr\b','grd.tctr'],
   [r'\bbpolfix\b','grd.bpolfix'],
   [r'\bbtfix\b','grd.btfix'],
   [r'\bisgdistort\b','grd.isgdistort'],
   [r'\bagsindx\b','grd.agsindx'],
   [r'\bagsrsp\b','grd.agsrsp'],
   [r'\biynod\b','grd.iynod'],
   [r'\brnod\b','grd.rnod'],
   [r'\bixdstar\b','grd.ixdstar'],
   [r'\bacore\b','grd.acore'],
   [r'\brm0\b','grd.rm0'],
   [r'\bedgewid\b','grd.edgewid'],
   [r'\bdthlim\b','grd.dthlim'],
   [r'\bbpol0\b','grd.bpol0'],
   [r'\bbtor0\b','grd.btor0'],
   [r'\bradf\b','grd.radf'],
   [r'\bthpf\b','grd.thpf'],
   [r'\bibpmodel\b','grd.ibpmodel'],
   [r'\bzu\b','grd.zu'],
   [r'\bru\b','grd.ru'],
   [r'\bbzu\b','grd.bzu'],
   [r'\bbru\b','grd.bru'],
   [r'\bbmag\b','grd.bmag'],
   [r'\bnzc\b','grd.nzc'],
   [r'\bnrc\b','grd.nrc'],
   [r'\bxcurveg\b','grd.xcurveg'],
   [r'\bycurveg\b','grd.ycurveg'],
   [r'\bnpointg\b','grd.npointg'],
   [r'\bxxpoint\b','grd.xxpoint'],
   [r'\byxpoint\b','grd.yxpoint'],
   [r'\brtanpl\b','grd.rtanpl'],
   [r'\bztanpl\b','grd.ztanpl'],
   [r'\bcmeshx\b','grd.cmeshx'],
   [r'\bcmeshy\b','grd.cmeshy'],
   [r'\bixpoint\b','grd.ixpoint'],
   [r'\byextend\b','grd.yextend'],
   [r'\bdsmin\b','grd.dsmin'],
   [r'\bdsminx\b','grd.dsminx'],
   [r'\bdyjump\b','grd.dyjump'],
   [r'\balpha1\b','grd.alpha1'],
   [r'\bityp\b','grd.ityp'],
   [r'\bdxleft\b','grd.dxleft'],
   [r'\bndxleft\b','grd.ndxleft'],
   [r'\bisegment\b','grd.isegment'],
   [r'\bisys\b','grd.isys'],
   [r'\balphasys\b','grd.alphasys'],
   [r'\bijump\b','grd.ijump'],
   [r'\bsplcoef\b','grd.splcoef'],
   [r'\bxknts\b','grd.xknts'],
   [r'\bncap7\b','grd.ncap7'],
   [r'\bxdatag\b','grd.xdatag'],
   [r'\bydatag\b','grd.ydatag'],
   [r'\bsddata\b','grd.sddata'],
   [r'\bnord\b','grd.nord'],
   [r'\bbkpt\b','grd.bkpt'],
   [r'\bxconst\b','grd.xconst'],
   [r'\byconst\b','grd.yconst'],
   [r'\bnderiv\b','grd.nderiv'],
   [r'\bmode\b','grd.mode'],
   [r'\bcoeff\b','grd.coeff'],
   [r'\bwsla\b','grd.wsla'],
   [r'\biwsla\b','grd.iwsla'],
   [r'\bisspnew\b','grd.isspnew'],
   [r'\brstrike\b','grd.rstrike'],
   [r'\bzstrike\b','grd.zstrike'],
   [r'\bistpnew\b','grd.istpnew'],
   [r'\brtpnew\b','grd.rtpnew'],
   [r'\bztpnew\b','grd.ztpnew'],
   [r'\bistptest\b','grd.istptest'],
   [r'\bilmax\b','grd.ilmax'],
   [r'\bseedxp\b','grd.seedxp'],
   [r'\bseedxpxl\b','grd.seedxpxl'],
   [r'\bseed\b','grd.seed'],
   [r'\bdissep\b','grd.dissep'],
   [r'\bdistxp\b','grd.distxp'],
   [r'\bdistxpxl\b','grd.distxpxl'],
   [r'\bx0g\b','grd.x0g'],
   [r'\bxlast\b','grd.xlast'],
   [r'\by0g\b','grd.y0g'],
   [r'\bylast\b','grd.ylast'],
   [r'\bisztest\b','grd.isztest'],
   [r'\bepslon_lim\b','grd.epslon_lim'],
   [r'\bdalpha\b','grd.dalpha'],
   [r'\bxtrans\b','grd.xtrans'],
   [r'\bytrans\b','grd.ytrans'],
   [r'\bwg\b','grd.wg'],
   [r'\bistartg\b','grd.istartg'],
   [r'\biendg\b','grd.iendg'],
   [r'\bm\b','grd.m'],
   [r'\bnseg\b','grd.nseg'],
   [r'\bixpointc\b','grd.ixpointc'],
   [r'\bxwork\b','grd.xwork'],
   [r'\bywork\b','grd.ywork'],
   [r'\bistartc\b','grd.istartc'],
   [r'\biendc\b','grd.iendc'],
   [r'\bixtop\b','grd.ixtop'],
   [r'\bcmeshx0\b','grd.cmeshx0'],
   [r'\bcmeshy0\b','grd.cmeshy0'],
   [r'\bdsc\b','grd.dsc'],
   [r'\bxcrv\b','grd.xcrv'],
   [r'\bycrv\b','grd.ycrv'],
   [r'\bdsm\b','grd.dsm'],
   [r'\bdss\b','grd.dss'],
   [r'\bdssleg\b','grd.dssleg'],
   [r'\bdsmesh\b','grd.dsmesh'],
   [r'\bdsmesh0\b','grd.dsmesh0'],
   [r'\bdsmesh1\b','grd.dsmesh1'],
   [r'\bdsmesh2\b','grd.dsmesh2'],
   [r'\bxmsh\b','grd.xmsh'],
   [r'\bymsh\b','grd.ymsh'],
   [r'\bntop1\b','grd.ntop1'],
   [r'\brtop1\b','grd.rtop1'],
   [r'\bztop1\b','grd.ztop1'],
   [r'\bntop2\b','grd.ntop2'],
   [r'\brtop2\b','grd.rtop2'],
   [r'\bztop2\b','grd.ztop2'],
   [r'\bistream\b','grd.istream'],
   [r'\bisupstreamx\b','grd.isupstreamx'],
   [r'\bnupstream1\b','grd.nupstream1'],
   [r'\brupstream1\b','grd.rupstream1'],
   [r'\bzupstream1\b','grd.zupstream1'],
   [r'\bnupstream2\b','grd.nupstream2'],
   [r'\brupstream2\b','grd.rupstream2'],
   [r'\bzupstream2\b','grd.zupstream2'],
   [r'\bndnstream1\b','grd.ndnstream1'],
   [r'\brdnstream1\b','grd.rdnstream1'],
   [r'\bzdnstream1\b','grd.zdnstream1'],
   [r'\bndnstream2\b','grd.ndnstream2'],
   [r'\brdnstream2\b','grd.rdnstream2'],
   [r'\bzdnstream2\b','grd.zdnstream2'],
   [r'\biplate\b','grd.iplate'],
   [r'\bnplate1\b','grd.nplate1'],
   [r'\brplate1\b','grd.rplate1'],
   [r'\bzplate1\b','grd.zplate1'],
   [r'\bnplate2\b','grd.nplate2'],
   [r'\brplate2\b','grd.rplate2'],
   [r'\bzplate2\b','grd.zplate2'],
   [r'\bntop\b','grd.ntop'],
   [r'\brtop\b','grd.rtop'],
   [r'\bztop\b','grd.ztop'],
   [r'\bntop0\b','grd.ntop0'],
   [r'\brtop0\b','grd.rtop0'],
   [r'\bztop0\b','grd.ztop0'],
   [r'\bnbot\b','grd.nbot'],
   [r'\brbot\b','grd.rbot'],
   [r'\bzbot\b','grd.zbot'],
   [r'\bnupstream\b','grd.nupstream'],
   [r'\brupstream\b','grd.rupstream'],
   [r'\bzupstream\b','grd.zupstream'],
   [r'\bndnstream\b','grd.ndnstream'],
   [r'\brdnstream\b','grd.rdnstream'],
   [r'\bzdnstream\b','grd.zdnstream'],
   [r'\bnplate\b','grd.nplate'],
   [r'\brplate\b','grd.rplate'],
   [r'\bzplate\b','grd.zplate'],
   [r'\bnplate0\b','grd.nplate0'],
   [r'\brplate0\b','grd.rplate0'],
   [r'\bzplate0\b','grd.zplate0'],
   [r'\bdsnorm\b','grd.dsnorm'],
   [r'\bwtold\b','grd.wtold'],
   [r'\bnsmooth\b','grd.nsmooth'],
   [r'\bfuzzm\b','grd.fuzzm'],
   [r'\bdelmax\b','grd.delmax'],
   [r'\bwtmesh1\b','grd.wtmesh1'],
   [r'\bwtm1\b','grd.wtm1'],
   [r'\bdmix0\b','grd.dmix0'],
   [r'\bcmeshx3\b','grd.cmeshx3'],
   [r'\bcmeshy3\b','grd.cmeshy3'],
   [r'\bnff1\b','grd.nff1'],
   [r'\brff1\b','grd.rff1'],
   [r'\bzff1\b','grd.zff1'],
   [r'\bnff2\b','grd.nff2'],
   [r'\brff2\b','grd.rff2'],
   [r'\bzff2\b','grd.zff2'],
   [r'\bnff\b','grd.nff'],
   [r'\brff\b','grd.rff'],
   [r'\bzff\b','grd.zff'],
   [r'\bdsmesh3\b','grd.dsmesh3'],
   [r'\bdsmeshff\b','grd.dsmeshff'],
   [r'\bcwtffu\b','grd.cwtffu'],
   [r'\bcwtffd\b','grd.cwtffd'],
   [r'\bisxtform\b','grd.isxtform'],
   [r'\biswtform\b','grd.iswtform'],
   [r'\bwtff1\b','grd.wtff1'],
   [r'\bslpxff1\b','grd.slpxff1'],
   [r'\bslpxffu1\b','grd.slpxffu1'],
   [r'\bslpxffd1\b','grd.slpxffd1'],
   [r'\bnxdff1\b','grd.nxdff1'],
   [r'\bwtff2\b','grd.wtff2'],
   [r'\bslpxff2\b','grd.slpxff2'],
   [r'\bslpxffu2\b','grd.slpxffu2'],
   [r'\bslpxffd2\b','grd.slpxffd2'],
   [r'\bnxdff2\b','grd.nxdff2'],
   [r'\bisrefxptn\b','grd.isrefxptn'],
   [r'\bnxmod\b','grd.nxmod'],
   [r'\balfxptl\b','grd.alfxptl'],
   [r'\balfxpt2l\b','grd.alfxpt2l'],
   [r'\balfxptu\b','grd.alfxptu'],
   [r'\balfxpt2u\b','grd.alfxpt2u'],
   [r'\balfxpt\b','grd.alfxpt'],
   [r'\balfxpt2\b','grd.alfxpt2'],
   [r'\brsu\b','grd.rsu'],
   [r'\bzsu\b','grd.zsu'],
   [r'\brsx\b','grd.rsx'],
   [r'\bzsx\b','grd.zsx'],
   [r'\bnflux\b','grd.nflux'],
   [r'\brflux\b','grd.rflux'],
   [r'\bzflux\b','grd.zflux'],
   [r'\bdsflux\b','grd.dsflux'],
   [r'\brmm\b','grd.rmm'],
   [r'\bzmm\b','grd.zmm'],
   [r'\bnsmoothx\b','grd.nsmoothx'],
   [r'\bndat\b','grd.ndat'],
   [r'\bxdat\b','grd.xdat'],
   [r'\btdat\b','grd.tdat'],
   [r'\bkxmesh\b','grd.kxmesh'],
   [r'\bslpxt\b','grd.slpxt'],
   [r'\balfx\b','grd.alfx'],
   [r'\bdxgas\b','grd.dxgas'],
   [r'\bnxgas\b','grd.nxgas'],
   [r'\bdt1\b','grd.dt1'],
   [r'\bdx1\b','grd.dx1'],
   [r'\bdt2\b','grd.dt2'],
   [r'\bdx2\b','grd.dx2'],
   [r'\bileft\b','grd.ileft'],
   [r'\bdleft\b','grd.dleft'],
   [r'\biright\b','grd.iright'],
   [r'\bdright\b','grd.dright'],
   [r'\bkord\b','grd.kord'],
   [r'\bndatp2\b','grd.ndatp2'],
   [r'\bkntopt\b','grd.kntopt'],
   [r'\btknt\b','grd.tknt'],
   [r'\bz1work\b','grd.z1work'],
   [r'\bz1cscoef\b','grd.z1cscoef'],
   [r'\bwrk1\b','grd.wrk1'],
   [r'\biflag1\b','grd.iflag1'],
   [r'\bnxmb\b','grd.nxmb'],
   [r'\bnymb\b','grd.nymb'],
   [r'\brmb\b','grd.rmb'],
   [r'\bzmb\b','grd.zmb'],
   [r'\bixpt1b\b','grd.ixpt1b'],
   [r'\bixtopb\b','grd.ixtopb'],
   [r'\bixpt2b\b','grd.ixpt2b'],
   [r'\biysptrxb\b','grd.iysptrxb'],
   [r'\bnxmu\b','grd.nxmu'],
   [r'\bnymu\b','grd.nymu'],
   [r'\brmu\b','grd.rmu'],
   [r'\bzmu\b','grd.zmu'],
   [r'\bixpt1u\b','grd.ixpt1u'],
   [r'\bixtopu\b','grd.ixtopu'],
   [r'\bixpt2u\b','grd.ixpt2u'],
   [r'\biysptrxu\b','grd.iysptrxu'],
   [r'\bfraclplt\b','grd.fraclplt'],
   [r'\balfxdiv\b','grd.alfxdiv'],
   [r'\balfxcore\b','grd.alfxcore'],
   [r'\bshift_seed_leg\b','grd.shift_seed_leg'],
   [r'\bshift_seed_core\b','grd.shift_seed_core'],
   [r'\bnxlplt\b','grd.nxlplt'],
   [r'\bnxlxpt\b','grd.nxlxpt'],
   [r'\bfcorenunif\b','grd.fcorenunif'],
   [r'\bnx\b','com.nx'],
   [r'\bny\b','com.ny'],
   [r'\bnxm\b','com.nxm'],
   [r'\bnym\b','com.nym'],
   [r'\bnxpt\b','com.nxpt'],
   [r'\bnhsp\b','com.nhsp'],
   [r'\bnzsp\b','com.nzsp'],
   [r'\bnzspt\b','com.nzspt'],
   [r'\bnzspmx\b','com.nzspmx'],
   [r'\bnisp\b','com.nisp'],
   [r'\bnusp\b','com.nusp'],
   [r'\bnfsp\b','com.nfsp'],
   [r'\bngsp\b','com.ngsp'],
   [r'\bnhgsp\b','com.nhgsp'],
   [r'\bimx\b','com.imx'],
   [r'\bimy\b','com.imy'],
   [r'\blnst\b','com.lnst'],
   [r'\bnum_elem\b','com.num_elem'],
   [r'\bjdim\b','com.jdim'],
   [r'\bnpts\b','com.npts'],
   [r'\bnoregs\b','com.noregs'],
   [r'\bnxefit\b','com.nxefit'],
   [r'\bnyefit\b','com.nyefit'],
   [r'\bnlim\b','com.nlim'],
   [r'\bnbdry\b','com.nbdry'],
   [r'\bnwork\b','com.nwork'],
   [r'\bisfw\b','com.isfw'],
   [r'\brunid\b','com.runid'],
   [r'\bxold\b','com.xold'],
   [r'\byold\b','com.yold'],
   [r'\bfold\b','com.fold'],
   [r'\bbcentr\b','com.bcentr'],
   [r'\brcentr\b','com.rcentr'],
   [r'\brmagx\b','com.rmagx'],
   [r'\bzmagx\b','com.zmagx'],
   [r'\bsimagx\b','com.simagx'],
   [r'\bsibdry\b','com.sibdry'],
   [r'\bsibdry1\b','com.sibdry1'],
   [r'\bsibdry2\b','com.sibdry2'],
   [r'\bxdim\b','com.xdim'],
   [r'\bzdim\b','com.zdim'],
   [r'\bzmid\b','com.zmid'],
   [r'\bzshift\b','com.zshift'],
   [r'\bworkk\b','com.workk'],
   [r'\bfpol\b','com.fpol'],
   [r'\bpres\b','com.pres'],
   [r'\bqpsi\b','com.qpsi'],
   [r'\brgrid1\b','com.rgrid1'],
   [r'\bcpasma\b','com.cpasma'],
   [r'\brbdry\b','com.rbdry'],
   [r'\bzbdry\b','com.zbdry'],
   [r'\bxlim\b','com.xlim'],
   [r'\bylim\b','com.ylim'],
   [r'\bbscoef\b','com.bscoef'],
   [r'\bkxord\b','com.kxord'],
   [r'\bkyord\b','com.kyord'],
   [r'\bxknot\b','com.xknot'],
   [r'\byknot\b','com.yknot'],
   [r'\bldf\b','com.ldf'],
   [r'\biflag\b','com.iflag'],
   [r'\bwork\b','com.work'],
   [r'\bjmin\b','com.jmin'],
   [r'\bjmax\b','com.jmax'],
   [r'\bjsptrx\b','com.jsptrx'],
   [r'\bjaxis\b','com.jaxis'],
   [r'\bxlbnd\b','com.xlbnd'],
   [r'\bxubnd\b','com.xubnd'],
   [r'\bylbnd\b','com.ylbnd'],
   [r'\byubnd\b','com.yubnd'],
   [r'\bxcurve\b','com.xcurve'],
   [r'\bycurve\b','com.ycurve'],
   [r'\bnpoint\b','com.npoint'],
   [r'\bvmonth\b','com.vmonth'],
   [r'\bvday\b','com.vday'],
   [r'\bvyear\b','com.vyear'],
   [r'\beshot\b','com.eshot'],
   [r'\betime\b','com.etime'],
   [r'\brseps\b','com.rseps'],
   [r'\bzseps\b','com.zseps'],
   [r'\brseps1\b','com.rseps1'],
   [r'\bzseps1\b','com.zseps1'],
   [r'\brseps2\b','com.rseps2'],
   [r'\bzseps2\b','com.zseps2'],
   [r'\brvsin\b','com.rvsin'],
   [r'\bzvsin\b','com.zvsin'],
   [r'\brvsout\b','com.rvsout'],
   [r'\bzvsout\b','com.zvsout'],
   [r'\bmco2v\b','com.mco2v'],
   [r'\bmco2r\b','com.mco2r'],
   [r'\brco2v\b','com.rco2v'],
   [r'\bdco2v\b','com.dco2v'],
   [r'\brco2r\b','com.rco2r'],
   [r'\bdco2r\b','com.dco2r'],
   [r'\bnsilop\b','com.nsilop'],
   [r'\bcsilop\b','com.csilop'],
   [r'\bmagpri\b','com.magpri'],
   [r'\bcmpr2\b','com.cmpr2'],
   [r'\bnfcoil\b','com.nfcoil'],
   [r'\bccbrsp\b','com.ccbrsp'],
   [r'\bnesum\b','com.nesum'],
   [r'\beccurt\b','com.eccurt'],
   [r'\brm\b','com.rm'],
   [r'\bzm\b','com.zm'],
   [r'\brmt\b','com.rmt'],
   [r'\bzmt\b','com.zmt'],
   [r'\brv\b','com.rv'],
   [r'\bzv\b','com.zv'],
   [r'\bpsi\b','com.psi'],
   [r'\bbr\b','com.br'],
   [r'\bbz\b','com.bz'],
   [r'\bbpol\b','com.bpol'],
   [r'\bbphi\b','com.bphi'],
   [r'\bb\b','com.b'],
   [r'\bbsqr\b','com.bsqr'],
   [r'\bb12\b','com.b12'],
   [r'\bb12ctr\b','com.b12ctr'],
   [r'\bb32\b','com.b32'],
   [r'\brmg\b','com.rmg'],
   [r'\bzmg\b','com.zmg'],
   [r'\bpsig\b','com.psig'],
   [r'\bbrg\b','com.brg'],
   [r'\bbzg\b','com.bzg'],
   [r'\bbpolg\b','com.bpolg'],
   [r'\bbphig\b','com.bphig'],
   [r'\bbg\b','com.bg'],
   [r'\bnycore\b','com.nycore'],
   [r'\bnysol\b','com.nysol'],
   [r'\bnyout\b','com.nyout'],
   [r'\bnxleg\b','com.nxleg'],
   [r'\bnxcore\b','com.nxcore'],
   [r'\bnxomit\b','com.nxomit'],
   [r'\bnxxpt\b','com.nxxpt'],
   [r'\bnyomitmx\b','com.nyomitmx'],
   [r'\bigrid\b','com.igrid'],
   [r'\bgeometry\b','com.geometry'],
   [r'\bnxc\b','com.nxc'],
   [r'\bsimagxs\b','com.simagxs'],
   [r'\bsibdrys\b','com.sibdrys'],
   [r'\bismpsym\b','com.ismpsym'],
   [r'\bislimon\b','com.islimon'],
   [r'\bix_lim\b','com.ix_lim'],
   [r'\biy_lims\b','com.iy_lims'],
   [r'\btheta_split\b','com.theta_split'],
   [r'\bisnonog\b','com.isnonog'],
   [r'\bismmon\b','com.ismmon'],
   [r'\bisoldgrid\b','com.isoldgrid'],
   [r'\bisgrdsym\b','com.isgrdsym'],
   [r'\bcutlo\b','com.cutlo'],
   [r'\bepslon\b','com.epslon'],
   [r'\bspheromak\b','com.spheromak'],
   [r'\bisfrc\b','com.isfrc'],
   [r'\bishalfm\b','com.ishalfm'],
   [r'\bisbphicon\b','com.isbphicon'],
   [r'\bnhdf\b','com.nhdf'],
   [r'\bhdfilename\b','com.hdfilename'],
   [r'\bnzdf\b','com.nzdf'],
   [r'\bmcfilename\b','com.mcfilename'],
   [r'\bcoronalimpfname\b','com.coronalimpfname'],
   [r'\bistabon\b','com.istabon'],
   [r'\breset_core_og\b','com.reset_core_og'],
   [r'\bixlb\b','com.ixlb'],
   [r'\bixpt1\b','com.ixpt1'],
   [r'\bixmdp\b','com.ixmdp'],
   [r'\bixpt2\b','com.ixpt2'],
   [r'\bixrb\b','com.ixrb'],
   [r'\biysptrx1\b','com.iysptrx1'],
   [r'\biysptrx2\b','com.iysptrx2'],
   [r'\biysptrx\b','com.iysptrx'],
   [r'\bixcut1\b','com.ixcut1'],
   [r'\bixcut2\b','com.ixcut2'],
   [r'\bixcut3\b','com.ixcut3'],
   [r'\bixcut4\b','com.ixcut4'],
   [r'\biycut1\b','com.iycut1'],
   [r'\biycut2\b','com.iycut2'],
   [r'\biycut3\b','com.iycut3'],
   [r'\biycut4\b','com.iycut4'],
   [r'\bvol\b','com.vol'],
   [r'\bgx\b','com.gx'],
   [r'\bgy\b','com.gy'],
   [r'\bdx\b','com.dx'],
   [r'\bdxvf\b','com.dxvf'],
   [r'\bdy\b','com.dy'],
   [r'\bgxf\b','com.gxf'],
   [r'\bgxfn\b','com.gxfn'],
   [r'\bgyf\b','com.gyf'],
   [r'\bgxc\b','com.gxc'],
   [r'\bgyc\b','com.gyc'],
   [r'\bxnrm\b','com.xnrm'],
   [r'\bxvnrm\b','com.xvnrm'],
   [r'\bynrm\b','com.ynrm'],
   [r'\byvnrm\b','com.yvnrm'],
   [r'\bsx\b','com.sx'],
   [r'\bsy\b','com.sy'],
   [r'\brr\b','com.rr'],
   [r'\bxcs\b','com.xcs'],
   [r'\bxfs\b','com.xfs'],
   [r'\bxcwi\b','com.xcwi'],
   [r'\bxfwi\b','com.xfwi'],
   [r'\bxfpf\b','com.xfpf'],
   [r'\bxcpf\b','com.xcpf'],
   [r'\bxcwo\b','com.xcwo'],
   [r'\bxfwo\b','com.xfwo'],
   [r'\byyc\b','com.yyc'],
   [r'\byyf\b','com.yyf'],
   [r'\byylb\b','com.yylb'],
   [r'\byyrb\b','com.yyrb'],
   [r'\bxcv\b','com.xcv'],
   [r'\bxfv\b','com.xfv'],
   [r'\bpsinormc\b','com.psinormc'],
   [r'\bpsinormf\b','com.psinormf'],
   [r'\brrv\b','com.rrv'],
   [r'\bvolv\b','com.volv'],
   [r'\bhxv\b','com.hxv'],
   [r'\bsyv\b','com.syv'],
   [r'\bsygytotc\b','com.sygytotc'],
   [r'\barea_core\b','com.area_core'],
   [r'\bghxpt\b','com.ghxpt'],
   [r'\bgvxpt\b','com.gvxpt'],
   [r'\bsxyxpt\b','com.sxyxpt'],
   [r'\bghxpt_lower\b','com.ghxpt_lower'],
   [r'\bgvxpt_lower\b','com.gvxpt_lower'],
   [r'\bsxyxpt_lower\b','com.sxyxpt_lower'],
   [r'\bghxpt_upper\b','com.ghxpt_upper'],
   [r'\bgvxpt_upper\b','com.gvxpt_upper'],
   [r'\bsxyxpt_upper\b','com.sxyxpt_upper'],
   [r'\blinelen\b','com.linelen'],
   [r'\bisxptx\b','com.isxptx'],
   [r'\bisxpty\b','com.isxpty'],
   [r'\blcon\b','com.lcon'],
   [r'\blconi\b','com.lconi'],
   [r'\blcone\b','com.lcone'],
   [r'\blconneo\b','com.lconneo'],
   [r'\bepsneo\b','com.epsneo'],
   [r'\bisixcore\b','com.isixcore'],
   [r'\bdxmin\b','com.dxmin'],
   [r'\blcong\b','com.lcong'],
   [r'\blconig\b','com.lconig'],
   [r'\blconeg\b','com.lconeg'],
   [r'\bvtag\b','com.vtag'],
   [r'\bangfx\b','com.angfx'],
   [r'\bfxm\b','com.fxm'],
   [r'\bfx0\b','com.fx0'],
   [r'\bfxp\b','com.fxp'],
   [r'\bfym\b','com.fym'],
   [r'\bfy0\b','com.fy0'],
   [r'\bfyp\b','com.fyp'],
   [r'\bfxmy\b','com.fxmy'],
   [r'\bfxpy\b','com.fxpy'],
   [r'\bfymx\b','com.fymx'],
   [r'\bfypx\b','com.fypx'],
   [r'\bfxmv\b','com.fxmv'],
   [r'\bfx0v\b','com.fx0v'],
   [r'\bfxpv\b','com.fxpv'],
   [r'\bfymv\b','com.fymv'],
   [r'\bfy0v\b','com.fy0v'],
   [r'\bfypv\b','com.fypv'],
   [r'\bfxmyv\b','com.fxmyv'],
   [r'\bfxpyv\b','com.fxpyv'],
   [r'\bfymxv\b','com.fymxv'],
   [r'\bfypxv\b','com.fypxv'],
   [r'\bistimingon\b','com.istimingon'],
   [r'\biprinttim\b','com.iprinttim'],
   [r'\bttotfe\b','com.ttotfe'],
   [r'\bttimpfe\b','com.ttimpfe'],
   [r'\bttotjf\b','com.ttotjf'],
   [r'\bttimpjf\b','com.ttimpjf'],
   [r'\bttmatfac\b','com.ttmatfac'],
   [r'\bttmatsol\b','com.ttmatsol'],
   [r'\bttjstor\b','com.ttjstor'],
   [r'\bttjrnorm\b','com.ttjrnorm'],
   [r'\bttjreorder\b','com.ttjreorder'],
   [r'\bttimpc\b','com.ttimpc'],
   [r'\btstart\b','com.tstart'],
   [r'\btend\b','com.tend'],
   [r'\bttnpg\b','com.ttnpg'],
   [r'\bttngxlog\b','com.ttngxlog'],
   [r'\bttngylog\b','com.ttngylog'],
   [r'\bttngfd2\b','com.ttngfd2'],
   [r'\bttngfxy\b','com.ttngfxy'],
   [r'\bnxbbb\b','com.nxbbb'],
   [r'\bnybbb\b','com.nybbb'],
   [r'\bnycorebbb\b','com.nycorebbb'],
   [r'\bnysolbbb\b','com.nysolbbb'],
   [r'\bnxleg1bbb\b','com.nxleg1bbb'],
   [r'\bnxcore1bbb\b','com.nxcore1bbb'],
   [r'\bnxleg2bbb\b','com.nxleg2bbb'],
   [r'\bnxcore2bbb\b','com.nxcore2bbb'],
   [r'\bgeometrybbb\b','com.geometrybbb'],
   [r'\bnibbb\b','com.nibbb'],
   [r'\btibbb\b','com.tibbb'],
   [r'\bnebbb\b','com.nebbb'],
   [r'\btebbb\b','com.tebbb'],
   [r'\bvflowxbbb\b','com.vflowxbbb'],
   [r'\bvflowybbb\b','com.vflowybbb'],
   [r'\bvflowzbbb\b','com.vflowzbbb'],
   [r'\bfnixbbb\b','com.fnixbbb'],
   [r'\bfngysibbb\b','com.fngysibbb'],
   [r'\bfngysobbb\b','com.fngysobbb'],
   [r'\btotb2val\b','com.totb2val'],
   [r'\btotintrv\b','com.totintrv'],
   [r'\bnlimu\b','com.nlimu'],
   [r'\brlimu\b','com.rlimu'],
   [r'\bzlimu\b','com.zlimu'],
   [r'\bnptnma\b','com.nptnma'],
   [r'\brptnma\b','com.rptnma'],
   [r'\bzptnma\b','com.zptnma'],
   [r'\bdslims\b','com.dslims'],
   [r'\bnsplit1\b','com.nsplit1'],
   [r'\brsplit1\b','com.rsplit1'],
   [r'\bzsplit1\b','com.zsplit1'],
   [r'\bnsplit2\b','com.nsplit2'],
   [r'\brsplit2\b','com.rsplit2'],
   [r'\bzsplit2\b','com.zsplit2'],
   [r'\bntev\b','com.ntev'],
   [r'\bnz\b','com.nz'],
   [r'\btevb\b','com.tevb'],
   [r'\brsi\b','com.rsi'],
   [r'\brre\b','com.rre'],
   [r'\brpwr\b','com.rpwr'],
   [r'\brrcx\b','com.rrcx'],
   [r'\blabelrt\b','com.labelrt'],
   [r'\brtnt\b','com.rtnt'],
   [r'\brtnn\b','com.rtnn'],
   [r'\brtns\b','com.rtns'],
   [r'\brtnsd\b','com.rtnsd'],
   [r'\brtza\b','com.rtza'],
   [r'\brtzn\b','com.rtzn'],
   [r'\brtza2\b','com.rtza2'],
   [r'\brtt\b','com.rtt'],
   [r'\brtn\b','com.rtn'],
   [r'\brtlt\b','com.rtlt'],
   [r'\brtln\b','com.rtln'],
   [r'\brtlsa\b','com.rtlsa'],
   [r'\brtlra\b','com.rtlra'],
   [r'\brtlqa\b','com.rtlqa'],
   [r'\brtlcx\b','com.rtlcx'],
   [r'\biscxfit\b','com.iscxfit'],
   [r'\bisrtndep\b','com.isrtndep'],
   [r'\bmcfformat\b','com.mcfformat'],
   [r'\bchgstate_format\b','com.chgstate_format'],
   [r'\bisprof_coef\b','com.isprof_coef'],
   [r'\bncoefne_tanh\b','com.ncoefne_tanh'],
   [r'\bncoefte_tanh\b','com.ncoefte_tanh'],
   [r'\bnumt_bs\b','com.numt_bs'],
   [r'\bnumc_bs\b','com.numc_bs'],
   [r'\bnumk_bs\b','com.numk_bs'],
   [r'\bfcoefne_tanh\b','com.fcoefne_tanh'],
   [r'\bfcoefte_tanh\b','com.fcoefte_tanh'],
   [r'\bfit_paramne_tanh\b','com.fit_paramne_tanh'],
   [r'\bfit_paramte_tanh\b','com.fit_paramte_tanh'],
   [r'\bfit_t_bs\b','com.fit_t_bs'],
   [r'\bfcoef_bs\b','com.fcoef_bs'],
   [r'\bnefit\b','com.nefit'],
   [r'\btefit\b','com.tefit'],
   [r'\btifit\b','com.tifit'],
   [r'\bnefituse\b','com.nefituse'],
   [r'\btefituse\b','com.tefituse'],
   [r'\btifituse\b','com.tifituse'],
   [r'\bfitfrac1\b','com.fitfrac1'],
   [r'\bdumfit\b','com.dumfit'],
   [r'\bisdatfmtnew\b','com.isdatfmtnew'],
   [r'\bpsishift\b','com.psishift'],
   [r'\bisdndtfitdat\b','com.isdndtfitdat'],
   [r'\bifitset\b','com.ifitset'],
   [r'\btim_interval_fit\b','com.tim_interval_fit'],
   [r'\btim_chng_max\b','com.tim_chng_max'],
   [r'\btaudndt\b','com.taudndt'],
   [r'\btaudeedt\b','com.taudeedt'],
   [r'\btaudeidt\b','com.taudeidt'],
   [r'\bisprofvspsi\b','com.isprofvspsi'],
   [r'\bepsi_fit\b','com.epsi_fit'],
   [r'\bpsi_s\b','com.psi_s'],
   [r'\byyc_fit\b','com.yyc_fit'],
   [r'\beprofile_fit\b','com.eprofile_fit'],
   [r'\bnsearch\b','flx.nsearch'],
   [r'\bistchkon\b','flx.istchkon'],
   [r'\bisthmmxn\b','flx.isthmmxn'],
   [r'\bdtheta_exclude\b','flx.dtheta_exclude'],
   [r'\bdtheta_overlap_sol\b','flx.dtheta_overlap_sol'],
   [r'\bdtheta_overlap_pf\b','flx.dtheta_overlap_pf'],
   [r'\bthetax\b','flx.thetax'],
   [r'\bthetamin\b','flx.thetamin'],
   [r'\bthetamax\b','flx.thetamax'],
   [r'\btheta1fac\b','flx.theta1fac'],
   [r'\btheta2fac\b','flx.theta2fac'],
   [r'\bymax1fac\b','flx.ymax1fac'],
   [r'\bymax2fac\b','flx.ymax2fac'],
   [r'\bimagx\b','flx.imagx'],
   [r'\bjmagx\b','flx.jmagx'],
   [r'\biseps\b','flx.iseps'],
   [r'\bjseps\b','flx.jseps'],
   [r'\bicutoff1\b','flx.icutoff1'],
   [r'\bjcutoff1\b','flx.jcutoff1'],
   [r'\bslpyt\b','flx.slpyt'],
   [r'\bslp2fac\b','flx.slp2fac'],
   [r'\bslp3fac\b','flx.slp3fac'],
   [r'\bpsifac\b','flx.psifac'],
   [r'\bpsi0sep1\b','flx.psi0sep1'],
   [r'\bpsi0sep2\b','flx.psi0sep2'],
   [r'\bpsi0max_inner\b','flx.psi0max_inner'],
   [r'\bpsi0max_outer\b','flx.psi0max_outer'],
   [r'\bpsi0min2_upper\b','flx.psi0min2_upper'],
   [r'\bpsi0min2_lower\b','flx.psi0min2_lower'],
   [r'\bpsi0min1\b','flx.psi0min1'],
   [r'\bpsi0min2\b','flx.psi0min2'],
   [r'\bpsi0sep\b','flx.psi0sep'],
   [r'\bpsi0max\b','flx.psi0max'],
   [r'\bpsi0lim\b','flx.psi0lim'],
   [r'\bsfaclim\b','flx.sfaclim'],
   [r'\balfcy_inner\b','flx.alfcy_inner'],
   [r'\balfcy\b','flx.alfcy'],
   [r'\bxoverlap\b','flx.xoverlap'],
   [r'\brho\b','flx.rho'],
   [r'\btflx\b','flx.tflx'],
   [r'\bpsitop\b','flx.psitop'],
   [r'\bpsibot\b','flx.psibot'],
   [r'\biseqdskr\b','flx.iseqdskr'],
   [r'\bkymesh\b','flx.kymesh'],
   [r'\bxcutoff1\b','flx.xcutoff1'],
   [r'\bycutoff1\b','flx.ycutoff1'],
   [r'\bmdsefit\b','flx.mdsefit'],
   [r'\bpsi0_mp_inner\b','flx.psi0_mp_inner'],
   [r'\bpsi0_mp_outer\b','flx.psi0_mp_outer'],
   [r'\bpsi0_dp_lower_inner\b','flx.psi0_dp_lower_inner'],
   [r'\bpsi0_dp_lower_outer\b','flx.psi0_dp_lower_outer'],
   [r'\bpsi0_dp_upper_inner\b','flx.psi0_dp_upper_inner'],
   [r'\bpsi0_dp_upper_outer\b','flx.psi0_dp_upper_outer'],
   [r'\bplflux0\b','flx.plflux0'],
   [r'\bncmin0\b','flx.ncmin0'],
   [r'\bncmax0\b','flx.ncmax0'],
   [r'\biserch0\b','flx.iserch0'],
   [r'\bjserch0\b','flx.jserch0'],
   [r'\bistepf0\b','flx.istepf0'],
   [r'\bjstepf0\b','flx.jstepf0'],
   [r'\bxminf0\b','flx.xminf0'],
   [r'\bxmaxf0\b','flx.xmaxf0'],
   [r'\byminf0\b','flx.yminf0'],
   [r'\bymaxf0\b','flx.ymaxf0'],
   [r'\bistcvon\b','flx.istcvon'],
   [r'\baltsearch\b','flx.altsearch'],
   [r'\bisetpath\b','flx.isetpath'],
   [r'\bncmin\b','flx.ncmin'],
   [r'\bncmax\b','flx.ncmax'],
   [r'\biserch\b','flx.iserch'],
   [r'\bjserch\b','flx.jserch'],
   [r'\bistepf\b','flx.istepf'],
   [r'\bjstepf\b','flx.jstepf'],
   [r'\bleadir\b','flx.leadir'],
   [r'\bncmin1\b','flx.ncmin1'],
   [r'\bncmax1\b','flx.ncmax1'],
   [r'\bplflux\b','flx.plflux'],
   [r'\bmrfac\b','flx.mrfac'],
   [r'\bnx4\b','flx.nx4'],
   [r'\bny4\b','flx.ny4'],
   [r'\bx\b','flx.x'],
   [r'\by\b','flx.y'],
   [r'\bf\b','flx.f'],
   [r'\bijumpf\b','flx.ijumpf'],
   [r'\bdsjumpf\b','flx.dsjumpf'],
   [r'\bilast\b','flx.ilast'],
   [r'\bxcn\b','flx.xcn'],
   [r'\bycn\b','flx.ycn'],
   [r'\bimin\b','flx.imin'],
   [r'\bimax\b','flx.imax'],
   [r'\bistart\b','flx.istart'],
   [r'\bjmins\b','flx.jmins'],
   [r'\bjmaxs\b','flx.jmaxs'],
   [r'\bjstart\b','flx.jstart'],
   [r'\bncontr\b','flx.ncontr'],
   [r'\bpfr\b','flx.pfr'],
   [r'\btwopie\b','flx.twopie'],
   [r'\bxminf\b','flx.xminf'],
   [r'\bxmaxf\b','flx.xmaxf'],
   [r'\byminf\b','flx.yminf'],
   [r'\bymaxf\b','flx.ymaxf'],
   [r'\brs_com\b','flx.rs_com'],
   [r'\bzs_com\b','flx.zs_com'],
   [r'\bev2\b','api.ev2'],
   [r'\bqe2\b','api.qe2'],
   [r'\bcrni\b','api.crni'],
   [r'\bctemp\b','api.ctemp'],
   [r'\bdnimp\b','api.dnimp'],
   [r'\bmethimp\b','api.methimp'],
   [r'\bcsexpn\b','api.csexpn'],
   [r'\bsimpfix\b','api.simpfix'],
   [r'\bnzsor\b','api.nzsor'],
   [r'\biszsorlb\b','api.iszsorlb'],
   [r'\bjxzsori\b','api.jxzsori'],
   [r'\bjxzsoro\b','api.jxzsoro'],
   [r'\bixzbegi\b','api.ixzbegi'],
   [r'\bixzendi\b','api.ixzendi'],
   [r'\bixzbego\b','api.ixzbego'],
   [r'\bixzendo\b','api.ixzendo'],
   [r'\bximpi\b','api.ximpi'],
   [r'\bximpo\b','api.ximpo'],
   [r'\bwimpi\b','api.wimpi'],
   [r'\bwimpo\b','api.wimpo'],
   [r'\bimpsori\b','api.impsori'],
   [r'\bimpsoro\b','api.impsoro'],
   [r'\binelrates\b','api.inelrates'],
   [r'\binelrad\b','api.inelrad'],
   [r'\binelmc\b','api.inelmc'],
   [r'\bncaset\b','api.ncaset'],
   [r'\bncaseno\b','api.ncaseno'],
   [r'\bncasent\b','api.ncasent'],
   [r'\bterad\b','api.terad'],
   [r'\bxno\b','api.xno'],
   [r'\brntau\b','api.rntau'],
   [r'\bradrate\b','api.radrate'],
   [r'\bavgz\b','api.avgz'],
   [r'\bavgz2\b','api.avgz2'],
   [r'\bapidir\b','api.apidir'],
   [r'\bnnz\b','api.nnz'],
   [r'\bzq\b','api.zq'],
   [r'\batn\b','api.atn'],
   [r'\batw\b','api.atw'],
   [r'\bnt\b','api.nt'],
   [r'\bnr\b','api.nr'],
   [r'\bnn\b','api.nn'],
   [r'\btdatm\b','api.tdatm'],
   [r'\brdatm\b','api.rdatm'],
   [r'\bndatm\b','api.ndatm'],
   [r'\bemdatm\b','api.emdatm'],
   [r'\bz1datm\b','api.z1datm'],
   [r'\bz2datm\b','api.z2datm'],
   [r'\bnxdata\b','api.nxdata'],
   [r'\bnydata\b','api.nydata'],
   [r'\bnzdata\b','api.nzdata'],
   [r'\bxdata\b','api.xdata'],
   [r'\bydata\b','api.ydata'],
   [r'\bzdata\b','api.zdata'],
   [r'\bfdata\b','api.fdata'],
   [r'\bldf\b','api.ldf'],
   [r'\bmdf\b','api.mdf'],
   [r'\biflagi\b','api.iflagi'],
   [r'\bnwork2\b','api.nwork2'],
   [r'\bwork2\b','api.work2'],
   [r'\bnwork3\b','api.nwork3'],
   [r'\bwork3\b','api.work3'],
   [r'\biworki\b','api.iworki'],
   [r'\bicont\b','api.icont'],
   [r'\bkxords\b','api.kxords'],
   [r'\bkyords\b','api.kyords'],
   [r'\bkzords\b','api.kzords'],
   [r'\bxknots\b','api.xknots'],
   [r'\byknots\b','api.yknots'],
   [r'\bzknots\b','api.zknots'],
   [r'\bemcoef\b','api.emcoef'],
   [r'\bz1coef\b','api.z1coef'],
   [r'\bz2coef\b','api.z2coef'],
   [r'\bcoulom\b','api.coulom'],
   [r'\bepsilo\b','api.epsilo'],
   [r'\bpromas\b','api.promas'],
   [r'\bxj7kv\b','api.xj7kv'],
   [r'\bone\b','api.one'],
   [r'\bpi0\b','api.pi0'],
   [r'\bzero\b','api.zero'],
   [r'\bsumforce\b','api.sumforce'],
   [r'\btotmass\b','api.totmass'],
   [r'\banorm\b','api.anorm'],
   [r'\bacci\b','api.acci'],
   [r'\bacci0\b','api.acci0'],
   [r'\bal32\b','api.al32'],
   [r'\bmiso\b','api.miso'],
   [r'\bnzch\b','api.nzch'],
   [r'\bmise\b','api.mise'],
   [r'\bilam1\b','api.ilam1'],
   [r'\bilam2\b','api.ilam2'],
   [r'\bilam3\b','api.ilam3'],
   [r'\biacci\b','api.iacci'],
   [r'\biforc\b','api.iforc'],
   [r'\bnatom\b','api.natom'],
   [r'\bcapm\b','api.capm'],
   [r'\bcapn\b','api.capn'],
   [r'\bcaplam\b','api.caplam'],
   [r'\bfmomenta\b','api.fmomenta'],
   [r'\bdenz\b','api.denz'],
   [r'\bdenmass\b','api.denmass'],
   [r'\bela\b','api.ela'],
   [r'\belab\b','api.elab'],
   [r'\bmntau\b','api.mntau'],
   [r'\busol\b','api.usol'],
   [r'\bsbar\b','api.sbar'],
   [r'\bzi\b','api.zi'],
   [r'\bceth\b','api.ceth'],
   [r'\bcetf\b','api.cetf'],
   [r'\bcq\b','api.cq'],
   [r'\bntars\b','api.ntars'],
   [r'\bcidata\b','api.cidata'],
   [r'\bredf_haas\b','api.redf_haas'],
   [r'\bntemp\b','api.ntemp'],
   [r'\bnlam\b','api.nlam'],
   [r'\bnden\b','api.nden'],
   [r'\betemp\b','api.etemp'],
   [r'\blamb\b','api.lamb'],
   [r'\beden\b','api.eden'],
   [r'\brate\b','api.rate'],
   [r'\bemiss\b','api.emiss'],
   [r'\bnrpix\b','api.nrpix'],
   [r'\bnzpix\b','api.nzpix'],
   [r'\bnpd\b','api.npd'],
   [r'\brp1\b','api.rp1'],
   [r'\bzp1\b','api.zp1'],
   [r'\brp2\b','api.rp2'],
   [r'\bzp2\b','api.zp2'],
   [r'\bwt\b','api.wt'],
   [r'\brminpix\b','api.rminpix'],
   [r'\brmaxpix\b','api.rmaxpix'],
   [r'\bzminpix\b','api.zminpix'],
   [r'\bzmaxpix\b','api.zmaxpix'],
   [r'\bdrpix\b','api.drpix'],
   [r'\bdzpix\b','api.dzpix'],
   [r'\bev\b','aph.ev'],
   [r'\bm_prot\b','aph.m_prot'],
   [r'\bissgvcxc\b','aph.issgvcxc'],
   [r'\bsgvcxc\b','aph.sgvcxc'],
   [r'\bisaphdir\b','aph.isaphdir'],
   [r'\baphdir\b','aph.aphdir'],
   [r'\bdata_directory\b','aph.data_directory'],
   [r'\berad\b','aph.erad'],
   [r'\blabelht\b','aph.labelht'],
   [r'\bhtns\b','aph.htns'],
   [r'\bhtnn\b','aph.htnn'],
   [r'\bhtnt\b','aph.htnt'],
   [r'\bhtza\b','aph.htza'],
   [r'\bhtzn\b','aph.htzn'],
   [r'\bhtn\b','aph.htn'],
   [r'\bhtt\b','aph.htt'],
   [r'\bhtln\b','aph.htln'],
   [r'\bhtlt\b','aph.htlt'],
   [r'\bhtlsa\b','aph.htlsa'],
   [r'\bhtlra\b','aph.htlra'],
   [r'\bhtlcx\b','aph.htlcx'],
   [r'\bhtlqa\b','aph.htlqa'],
   [r'\bmpe\b','aph.mpe'],
   [r'\bmpd\b','aph.mpd'],
   [r'\bmpr\b','aph.mpr'],
   [r'\bwsveh\b','aph.wsveh'],
   [r'\bwsveh0\b','aph.wsveh0'],
   [r'\bwlemiss\b','aph.wlemiss'],
   [r'\bwelms\b','aph.welms'],
   [r'\bwelms1\b','aph.welms1'],
   [r'\bwelms2\b','aph.welms2'],
   [r'\bpne3\b','aph.pne3'],
   [r'\bpne31\b','aph.pne31'],
   [r'\bpne32\b','aph.pne32'],
   [r'\bpne2\b','aph.pne2'],
   [r'\bpne21\b','aph.pne21'],
   [r'\bpne22\b','aph.pne22'],
   [r'\bpne41\b','aph.pne41'],
   [r'\bpne42\b','aph.pne42'],
   [r'\bpne51\b','aph.pne51'],
   [r'\bpne52\b','aph.pne52'],
   [r'\bpne61\b','aph.pne61'],
   [r'\bpne62\b','aph.pne62'],
   [r'\bpne71\b','aph.pne71'],
   [r'\bpne72\b','aph.pne72'],
   [r'\bpne81\b','aph.pne81'],
   [r'\bpne82\b','aph.pne82'],
   [r'\bpne91\b','aph.pne91'],
   [r'\bpne92\b','aph.pne92'],
   [r'\bsvdum2\b','aph.svdum2'],
   [r'\bsvphcx\b','aph.svphcx'],
   [r'\bekpt\b','aph.ekpt'],
   [r'\brlemin\b','aph.rlemin'],
   [r'\brlemax\b','aph.rlemax'],
   [r'\berefmin\b','aph.erefmin'],
   [r'\berefmax\b','aph.erefmax'],
   [r'\bdelekpt\b','aph.delekpt'],
   [r'\bdkpt\b','aph.dkpt'],
   [r'\brldmin\b','aph.rldmin'],
   [r'\brldmax\b','aph.rldmax'],
   [r'\bdrefmin\b','aph.drefmin'],
   [r'\bdrefmax\b','aph.drefmax'],
   [r'\bdeldkpt\b','aph.deldkpt'],
   [r'\btaumin\b','aph.taumin'],
   [r'\btaumax\b','aph.taumax'],
   [r'\bdeltau\b','aph.deltau'],
   [r'\bnxdata\b','aph.nxdata'],
   [r'\bnydata\b','aph.nydata'],
   [r'\bxdata\b','aph.xdata'],
   [r'\bydata\b','aph.ydata'],
   [r'\bfdata\b','aph.fdata'],
   [r'\bldf\b','aph.ldf'],
   [r'\biflag\b','aph.iflag'],
   [r'\bkxords\b','aph.kxords'],
   [r'\bkyords\b','aph.kyords'],
   [r'\bxknots\b','aph.xknots'],
   [r'\byknots\b','aph.yknots'],
   [r'\bworkh\b','aph.workh'],
   [r'\brsacoef\b','aph.rsacoef'],
   [r'\brracoef\b','aph.rracoef'],
   [r'\brqacoef\b','aph.rqacoef'],
   ['\(','['],
   ['\)',']'],
   [';','\n'],
   ['^ *',''],
   ['^\t*',''],
   [r'\bbbb.del\b','bbb.delpy'],
   [r'\ballocate\b','bbb.allocate()'],
   [r'\bexmain\b','bbb.exmain()'],
   ]


warnrules = [
   [r'\bbbb.difniv\b\[','difniv has one base 0 dim'],
   [r'\bbbb.difprv\b\[','difprv has one base 0 dim'],
   [r'\bbbb.difniv2\b\[','difniv2 has one base 0 dim'],
   ]
